@@ -92,8 +92,8 @@ if __name__ == '__main__':
     # outfmt5to6
     if args_dict["subcommand_name"] == "outfmt5To6":
 
-        from lib.common.util import printer_list
-        from api.common.genome.blast import outfmt5_read_big, keep_outfmt6_info
+        from toolbiox.lib.common.util import printer_list
+        from toolbiox.api.common.genome.blast import outfmt5_read_big, keep_outfmt6_info
 
         input_file = args.input_file
         output_file = args.output_file
@@ -105,7 +105,7 @@ if __name__ == '__main__':
                     f.write(printer_list(hsp) + "\n")
 
     elif args_dict["subcommand_name"] == "outfmt5complete":
-        from api.common.genome.blast import outfmt5_complete
+        from toolbiox.api.common.genome.blast import outfmt5_complete
 
         if outfmt5_complete(args.input_file):
             print("%s is complete" % args.input_file)
@@ -114,7 +114,7 @@ if __name__ == '__main__':
 
     elif args_dict["subcommand_name"] == "genblasta2BED":
         import re
-        from lib.common.fileIO import tsv_file_dict_parse
+        from toolbiox.lib.common.fileIO import tsv_file_dict_parse
         """
         class abc(object):
             pass
@@ -151,7 +151,7 @@ if __name__ == '__main__':
                         contig_name, c_start, c_end, args.ID_prefix + str(num), score, gb_file[i]['strand']))
 
     elif args_dict["subcommand_name"] == "outfmt6ToFasta":
-        from lib.common.fileIO import tsv_file_dict_parse
+        from toolbiox.lib.common.fileIO import tsv_file_dict_parse
         from pyfaidx import Fasta
         from Bio.Seq import Seq
         from Bio.SeqRecord import SeqRecord
@@ -200,7 +200,7 @@ if __name__ == '__main__':
         import re
         import os
         from BCBio import GFF
-        from lib.common.fileIO import tsv_file_dict_parse
+        from toolbiox.lib.common.fileIO import tsv_file_dict_parse
         from pyfaidx import Fasta
         """
         class abc(object):
@@ -461,7 +461,7 @@ if __name__ == '__main__':
 
     elif args_dict["subcommand_name"] == "MD5Checker":
         import os
-        from lib.common.os import cmd_run
+        from toolbiox.lib.common.os import cmd_run
 
 
         def check_md5(dir_path):
@@ -486,7 +486,7 @@ if __name__ == '__main__':
         check_md5(args.dir_path)
 
     elif args_dict["subcommand_name"] == "blast2DB":
-        from api.common.genome.blast import blast_to_sqlite
+        from toolbiox.api.common.genome.blast import blast_to_sqlite
 
         blast_to_sqlite(args.db_fasta, args.input_bls, None,
                         None, 6, None, None, None, False, args.gzip_flag)
@@ -503,9 +503,9 @@ if __name__ == '__main__':
         args.output_file = '/lustre/home/xuyuxing/Database/Plant_genome/clean_data/Gastrodia_elata/transcriptome/FPKM.txt'
         """
 
-        from lib.common.fileIO import tsv_file_dict_parse
-        from lib.common.util import printer_list
-        from lib.common.genome.genome_feature2 import read_gff_file, Gene
+        from toolbiox.lib.common.fileIO import tsv_file_dict_parse
+        from toolbiox.lib.common.util import printer_list
+        from toolbiox.lib.common.genome.genome_feature2 import read_gff_file, Gene
 
 
         def fpkm(count,length,mapped_count):
