@@ -7,19 +7,19 @@ import matplotlib
 
 matplotlib.use('Agg')
 
-# import lib.base.base_function as bf
-# from lib.config import *
-# from lib.seq.seq_base import read_fasta_big
+# import toolbiox.lib.base.base_function as bf
+# from toolbiox.lib.config import *
+# from toolbiox.lib.seq.seq_base import read_fasta_big
 # import os
-# from lib.file_parser.fileIO import tsv_file_parse
-# import lib.evolution.tree_operate_ete3 as to
+# from toolbiox.lib.file_parser.fileIO import tsv_file_parse
+# import toolbiox.lib.evolution.tree_operate_ete3 as to
 # import re
 # import sys
 # from Bio import Phylo
 # import networkx as nx
-# from lib.seq.blast import evalue_to_wvalue
+# from toolbiox.lib.seq.blast import evalue_to_wvalue
 # import pickle
-# from lib.evolution.tree_operate import lookup_by_names, normal_tree_rela_coord, normal_tree_abs_coord, draw_tree, \
+# from toolbiox.lib.evolution.tree_operate import lookup_by_names, normal_tree_rela_coord, normal_tree_abs_coord, draw_tree, \
 #     draw_ascii
 
 
@@ -630,7 +630,7 @@ if __name__ == '__main__':
     # command detail
 
     if args_dict["subcommand_name"] == "PtTree":
-        from src.xuyuxing.tools.phytools import PtTree
+        from toolbiox.src.xuyuxing.tools.phytools import PtTree
 
         in_file = args.protein_fasta
         phylogeneic_tree_builder = args.phylogeneic_tree_builder
@@ -643,7 +643,7 @@ if __name__ == '__main__':
                trimal_flag, output_dir, cpu_num, MSA)
 
     elif args_dict["subcommand_name"] == "TrueNtTree":
-        from src.xuyuxing.tools.phytools import TrueNtTree
+        from toolbiox.src.xuyuxing.tools.phytools import TrueNtTree
 
         in_file = args.nucl_fasta
         phylogeneic_tree_builder = args.phylogeneic_tree_builder
@@ -656,7 +656,7 @@ if __name__ == '__main__':
                    trimal_flag, output_dir, cpu_num, MSA)
 
     elif args_dict["subcommand_name"] == "PtNtTree":
-        from src.xuyuxing.tools.phytools import PtNtTree
+        from toolbiox.src.xuyuxing.tools.phytools import PtNtTree
 
         nucl_file = args.nucl_fasta
         pt_file = args.protein_fasta
@@ -669,7 +669,7 @@ if __name__ == '__main__':
                  trimal_flag, output_dir, cpu_num)
 
     elif args_dict["subcommand_name"] == "Print":
-        from lib.common.evolution.tree_operate import draw_ascii
+        from toolbiox.lib.common.evolution.tree_operate import draw_ascii
 
         tree = Phylo.read(args.tree_file, args.file_format)
 
@@ -690,7 +690,7 @@ if __name__ == '__main__':
         # print(tree_string)
 
     elif args_dict["subcommand_name"] == "SubTree":
-        import lib.xuyuxing.evolution.tree_operate_ete3 as to
+        import toolbiox.lib.xuyuxing.evolution.tree_operate_ete3 as to
 
         """
             tree_file = '/lustre/home/xuyuxing/Work/Cuscuta_HGT/123/HGT_case/case_001/genblastG/mcl/Cauv1.1_5.blast/Cauv1.1_5.blast.taxon.phb'
@@ -732,7 +732,7 @@ if __name__ == '__main__':
         pass
 
     elif args_dict["subcommand_name"] == "PartFamily":
-        from src.xuyuxing.tools.phytools import PartFamily
+        from toolbiox.src.xuyuxing.tools.phytools import PartFamily
 
         query = args.query
         database = args.database
@@ -784,7 +784,7 @@ if __name__ == '__main__':
         args.cpu_num=5
         args.blast_output = None
         """
-        from lib.common.os import cmd_run
+        from toolbiox.lib.common.os import cmd_run
 
         work_dir = os.path.dirname(args.input_fasta)
 
@@ -843,7 +843,7 @@ if __name__ == '__main__':
 
         # group seq to node (by a thre)
         import networkx as nx
-        from api.common.genome.blast import evalue_to_wvalue
+        from toolbiox.api.common.genome.blast import evalue_to_wvalue
 
         G = nx.Graph()
 
@@ -1106,7 +1106,7 @@ if __name__ == '__main__':
         args.ID_map_file = '/lustre/home/xuyuxing/Work/Balanophora/speci_tree/genome/OrthoFinder/Results_Nov02/WorkingDirectory/Alignments_ids/rename_map.txt'
         args.file_format = 'newick'
         """
-        from api.xuyuxing.file_parser.fileIO import tsv_file_parse
+        from toolbiox.api.xuyuxing.file_parser.fileIO import tsv_file_parse
 
         rename_map_dict = tsv_file_parse(args.ID_map_file, key_col=1)
 
@@ -1259,7 +1259,7 @@ if __name__ == '__main__':
         args.input_tree = '/lustre/home/xuyuxing/Work/Kena/version2/mcl/pr17/cluster/all/pr17.group.fasttree/xml/pr17.group.fasttree.node.xml'
         args.output_tree = '/lustre/home/xuyuxing/Work/Kena/version2/mcl/pr17/cluster/all/pr17.group.fasttree/xml/pr17.group.fasttree.node.root.xml'
         """
-        from lib.common.evolution.tree_operate import lookup_by_names
+        from toolbiox.lib.common.evolution.tree_operate import lookup_by_names
 
         tree = Phylo.read(args.input_tree, args.file_format)
 
@@ -1324,8 +1324,8 @@ if __name__ == '__main__':
         args.gene_list_file = '/lustre/home/xuyuxing/Database/Balanophora/Comp_genome/dongming/orthofinder_191218/output/topo_test/subfile6.output/OG0010028/tmp'
         """
 
-        from lib.common.evolution.tree_operate import monophyly
-        from lib.common.fileIO import read_list_file
+        from toolbiox.lib.common.evolution.tree_operate import monophyly
+        from toolbiox.lib.common.fileIO import read_list_file
 
         if not args.output_file is None:
             sys.stdout = open(args.output_file, 'w')
@@ -1346,8 +1346,8 @@ if __name__ == '__main__':
 
     elif args_dict["subcommand_name"] == "RootTreeBySpecies":
         from Bio import Phylo
-        from lib.common.fileIO import tsv_file_dict_parse
-        from src.xuyuxing.tools.phytools import RootGeneTree
+        from toolbiox.lib.common.fileIO import tsv_file_dict_parse
+        from toolbiox.src.xuyuxing.tools.phytools import RootGeneTree
 
         file_info = tsv_file_dict_parse(args.gene_to_species_map, fieldnames=[
                                         'g_id', 's_id'], key_col='g_id')
@@ -1364,7 +1364,7 @@ if __name__ == '__main__':
         Phylo.write(gene_tree_rooted, args.output_tree, 'newick')
 
     elif args_dict["subcommand_name"] == "EasyABSREL":
-        from src.xuyuxing.tools.hyphy_tools import easy_ABSREL
+        from toolbiox.src.xuyuxing.tools.hyphy_tools import easy_ABSREL
         import os
 
         args.rooted_gene_tree = os.path.realpath(args.rooted_gene_tree)
@@ -1375,7 +1375,7 @@ if __name__ == '__main__':
                     tree_format=args.tree_format, threads=args.threads)
 
     elif args_dict["subcommand_name"] == "EasyRELAX":
-        from src.xuyuxing.tools.hyphy_tools import easy_RELAX
+        from toolbiox.src.xuyuxing.tools.hyphy_tools import easy_RELAX
         import os
 
         args.rooted_gene_tree = os.path.realpath(args.rooted_gene_tree)
