@@ -1,7 +1,7 @@
 from Bio import Phylo
-from lib.common.evolution.tree_operate import lookup_by_names, add_clade_name, draw_ascii, get_MRCA_from_list, is_ancestors_of
-from lib.common.os import multiprocess_running
-from api.xuyuxing.evolution.PAML_tools import quick_get_dNdS
+from toolbiox.lib.common.evolution.tree_operate import lookup_by_names, add_clade_name, draw_ascii, get_MRCA_from_list, is_ancestors_of
+from toolbiox.lib.common.os import multiprocess_running
+from toolbiox.api.xuyuxing.evolution.PAML_tools import quick_get_dNdS
 from itertools import combinations
 
 
@@ -24,7 +24,6 @@ for i in gene_list:
     map_dict[i] = species
 
 
-
 def get_duplication_and_speciation_node(gene_tree, species_tree, map_dict, target_taxon_node):
     gene_tree_node_dict = lookup_by_names(gene_tree)
     species_tree_node_dict = lookup_by_names(species_tree)
@@ -59,7 +58,7 @@ def get_duplication_and_speciation_node(gene_tree, species_tree, map_dict, targe
 
                 if len(set(s1_species_list) & set(s2_species_list)) > 0:
                     D_flag = True
-            
+
             if D_flag:
                 DS_dict['D'].append(c_id)
             else:
@@ -183,8 +182,9 @@ def check_duplication_for_one_tree_one_node(gene_tree, species_tree, map_dict, t
 
     all_gene_dict = {}
     for c_id in DS_dict['D'] + DS_dict['S']:
-        all_gene_dict[c_id] = [(map_dict[i.name], i.name) for i in gene_tree_node_dict[c_id].get_terminals()]
-        
+        all_gene_dict[c_id] = [(map_dict[i.name], i.name)
+                               for i in gene_tree_node_dict[c_id].get_terminals()]
+
     return DS_dict, dup_pair_dict, all_gene_dict
 
 
@@ -247,7 +247,7 @@ def get_gene_pair_Ks(gene_pairs_list):
     args_list = []
     args_id_list = []
     for i in gene_pairs_list:
-        args_list.append((i,"/tmp"))
+        args_list.append((i, "/tmp"))
         args_id_list.append(i)
 
     mlt_out = multiprocess_running(
@@ -265,9 +265,9 @@ def get_gene_pair_Ks(gene_pairs_list):
 
 
 if __name__ == '__main__':
-    from api.xuyuxing.comp_genome.gene_duplication_count import check_duplication_for_all_tree_one_node
-    from lib.common.evolution.orthotools2 import OrthoGroups, read_species_info
-    from lib.common.evolution.tree_operate import draw_ascii, add_clade_name, lookup_by_names
+    from toolbiox.api.xuyuxing.comp_genome.gene_duplication_count import check_duplication_for_all_tree_one_node
+    from toolbiox.lib.common.evolution.orthotools2 import OrthoGroups, read_species_info
+    from toolbiox.lib.common.evolution.tree_operate import draw_ascii, add_clade_name, lookup_by_names
     from Bio import Phylo
     import re
 
@@ -286,15 +286,15 @@ if __name__ == '__main__':
     sp_info_dict = {i: sp_info_dict[i] for i in sp_info_dict if i in sp_list}
 
     # read fasta
-    from lib.common.genome.seq_base import read_fasta_by_faidx
+    from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx
     for sp_id in sp_info_dict:
         sp = sp_info_dict[sp_id]
         sp.cds_dict = read_fasta_by_faidx(sp.cds_file)
         sp.pt_dict = read_fasta_by_faidx(sp.pt_file)
 
     # get function
-    from api.xuyuxing.file_parser.interproscan_results import interproscan_results_parser
-    from lib.common.fileIO import tsv_file_dict_parse
+    from toolbiox.api.xuyuxing.file_parser.interproscan_results import interproscan_results_parser
+    from toolbiox.lib.common.fileIO import tsv_file_dict_parse
     import pickle
 
     ath_ortho_dir = '/lustre/home/xuyuxing/Work/Gel/orcWGD/orthofinder_ath/pt_file/OrthoFinder/Results_Jun10/Orthologues/Orthologues_Ath'
@@ -307,7 +307,7 @@ if __name__ == '__main__':
     ath_go_dict = {}
     for i in data_dict:
         ath_go_dict[i] = data_dict[i][13].split("; ")
-    
+
     for sp_id in sp_info_dict:
         # print(sp_id)
         sp = sp_info_dict[sp_id]
@@ -333,8 +333,9 @@ if __name__ == '__main__':
         # use interpro
         if sp.interpro_function_anno:
             interproscan_output_tsv = sp.interpro_function_anno
-            interpro_dict = interproscan_results_parser(interproscan_output_tsv)
-            
+            interpro_dict = interproscan_results_parser(
+                interproscan_output_tsv)
+
             for i in interpro_dict:
                 go_anno = []
                 for j in interpro_dict[i].domain_list:
@@ -343,15 +344,15 @@ if __name__ == '__main__':
                 go_anno = list(set(go_anno))
 
                 if i not in sp.go_dict or len(sp.go_dict[i]) == 0:
-                    sp.go_dict[i] = go_anno                
+                    sp.go_dict[i] = go_anno
 
     # orthogroups
     OGs = OrthoGroups(OG_tsv_file=OG_tsv_file, species_list=sp_list)
 
     # get tandom function
-    from lib.common.genome.genome_feature2 import read_gff_file
-    from lib.xuyuxing.base.base_function import multiprocess_running
-    from lib.common.genome.genome_feature2 import Gene
+    from toolbiox.lib.common.genome.genome_feature2 import read_gff_file
+    from toolbiox.lib.xuyuxing.base.base_function import multiprocess_running
+    from toolbiox.lib.common.genome.genome_feature2 import Gene
 
     def get_rank_dict(gff_file):
         gff_dict = read_gff_file(gff_file)
@@ -505,17 +506,18 @@ if __name__ == '__main__':
                 if len(ks_list) > 0:
                     ks = np.median(ks_list)
                     # if (0.0 < ks < 1.0):
-                    if ks_judge_function(ks):                    
+                    if ks_judge_function(ks):
                         D_node_list.append((og_id, d_node))
                     else:
                         S_node_list.append((og_id, d_node))
                 else:
                     S_node_list.append((og_id, d_node))
 
-        print(len(D_node_list), len(D_node_list + S_node_list), len(D_node_list)/len(D_node_list + S_node_list))
+        print(len(D_node_list), len(D_node_list + S_node_list),
+              len(D_node_list)/len(D_node_list + S_node_list))
 
         # GO
-        ## prepare gene list
+        # prepare gene list
         fore_node_dict = {}
         for og_id, node_id in D_node_list:
             fore_node_dict[(og_id, node_id)] = all_gene_dict[og_id][node_id]
@@ -524,7 +526,7 @@ if __name__ == '__main__':
         for og_id, node_id in D_node_list + S_node_list:
             back_node_dict[(og_id, node_id)] = all_gene_dict[og_id][node_id]
 
-        ## map function
+        # map function
         fore_node_go_dict = {}
         for og_id, node_id in fore_node_dict:
             node_function = []
@@ -543,27 +545,30 @@ if __name__ == '__main__':
                     node_function.extend(sp_info_dict[sp_id].go_dict[g_id])
             back_node_go_dict[(og_id, node_id)] = list(set(node_function))
 
-        ## GO enrich
-        from api.xuyuxing.resource.GO import  GO_enrichment_by_topGO
+        # GO enrich
+        from toolbiox.api.xuyuxing.resource.GO import GO_enrichment_by_topGO
         fore_nodename_list = [i[0] + "_" + i[1] for i in fore_node_go_dict]
-        back_nodename_dict = {i[0] + "_" + i[1]:back_node_go_dict[i] for i in back_node_go_dict}
+        back_nodename_dict = {i[0] + "_" + i[1]                              : back_node_go_dict[i] for i in back_node_go_dict}
 
-        GO_dict = GO_enrichment_by_topGO(fore_nodename_list, back_nodename_dict, Ontology='BP')
+        GO_dict = GO_enrichment_by_topGO(
+            fore_nodename_list, back_nodename_dict, Ontology='BP')
 
         import pandas as pd
 
-        df = pd.DataFrame(columns=(['GO_id', 'Rank_in_weight', 'Term', 'Annotated', 'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']))
+        df = pd.DataFrame(columns=(['GO_id', 'Rank_in_weight', 'Term', 'Annotated',
+                                    'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']))
 
         for i in GO_dict:
-            df.loc[i] = [GO_dict[i][j] for j in ['GO_id', 'Rank_in_weight', 'Term', 'Annotated', 'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']]
+            df.loc[i] = [GO_dict[i][j] for j in ['GO_id', 'Rank_in_weight', 'Term', 'Annotated',
+                                                 'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']]
 
-        writer=pd.ExcelWriter('/lustre/home/xuyuxing/Work/Gel/orcWGD/Ks/WGD/'+test_node+".xlsx")
+        writer = pd.ExcelWriter(
+            '/lustre/home/xuyuxing/Work/Gel/orcWGD/Ks/WGD/'+test_node+".xlsx")
         df.to_excel(writer)
         writer.save()
 
         return fore_nodename_list, back_nodename_dict
 
-
     def ks_judge_function_N6(ks):
         return 0.86317289 - 0.2735924 * 1.5 < ks < 0.86317289 + 0.2735924 * 1.5
 
@@ -590,48 +595,50 @@ if __name__ == '__main__':
 
     test_node_dict = {
         'N6': {
-            'id':'N6',
-            'function':ks_judge_function_N6,
+            'id': 'N6',
+            'function': ks_judge_function_N6,
         },
         'Vpl': {
-            'id':'Vpl',
-            'function':ks_judge_function_Vpl,
+            'id': 'Vpl',
+            'function': ks_judge_function_Vpl,
         },
         'Ash': {
-            'id':'Ash',
-            'function':ks_judge_function_Ash,
+            'id': 'Ash',
+            'function': ks_judge_function_Ash,
         },
         'N4': {
-            'id':'N4',
-            'function':ks_judge_function_N4,
+            'id': 'N4',
+            'function': ks_judge_function_N4,
         },
         'Aof': {
-            'id':'Aof',
-            'function':ks_judge_function_Aof,
+            'id': 'Aof',
+            'function': ks_judge_function_Aof,
         },
         'N6': {
-            'id':'N6',
-            'function':ks_judge_function_N6,
+            'id': 'N6',
+            'function': ks_judge_function_N6,
         },
         'N9': {
-            'id':'N9',
-            'function':ks_judge_function_N9,
+            'id': 'N9',
+            'function': ks_judge_function_N9,
         },
         'Acom': {
-            'id':'Acom',
-            'function':ks_judge_function_Acom,
+            'id': 'Acom',
+            'function': ks_judge_function_Acom,
         },
         'Sly': {
-            'id':'Sly',
-            'function':ks_judge_function_Sly,
+            'id': 'Sly',
+            'function': ks_judge_function_Sly,
         }
     }
 
     for test_node in test_node_dict:
-        fore_nodename_list, back_nodename_dict = test_a_node(test_node, test_node_dict[test_node]['function'])
-        test_node_dict[test_node]['output'] = (fore_nodename_list, back_nodename_dict)
+        fore_nodename_list, back_nodename_dict = test_a_node(
+            test_node, test_node_dict[test_node]['function'])
+        test_node_dict[test_node]['output'] = (
+            fore_nodename_list, back_nodename_dict)
 
-    ## for OG level
+    # for OG level
     back_OG_dict = {}
     for test_node in test_node_dict:
         fore_nodename_list, back_nodename_dict = test_node_dict[test_node]['output']
@@ -644,23 +651,28 @@ if __name__ == '__main__':
     for i in back_OG_dict:
         back_OG_dict[i] = list(set(back_OG_dict[i]))
 
-    from api.xuyuxing.resource.GO import  GO_enrichment_by_topGO
+    from toolbiox.api.xuyuxing.resource.GO import GO_enrichment_by_topGO
     import pandas as pd
 
     fore_OG_dict = {}
     for test_node in test_node_dict:
         fore_nodename_list, back_nodename_dict = test_node_dict[test_node]['output']
-        fore_OG_dict[test_node] = list(set([i.split("_", 1)[0] for i in fore_nodename_list]))
+        fore_OG_dict[test_node] = list(
+            set([i.split("_", 1)[0] for i in fore_nodename_list]))
         print(test_node, len(fore_OG_dict[test_node]))
 
-        GO_dict = GO_enrichment_by_topGO(fore_OG_dict[test_node], back_OG_dict, Ontology='BP')
+        GO_dict = GO_enrichment_by_topGO(
+            fore_OG_dict[test_node], back_OG_dict, Ontology='BP')
 
-        df = pd.DataFrame(columns=(['GO_id', 'Rank_in_weight', 'Term', 'Annotated', 'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']))
+        df = pd.DataFrame(columns=(['GO_id', 'Rank_in_weight', 'Term', 'Annotated',
+                                    'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']))
 
         for i in GO_dict:
-            df.loc[i] = [GO_dict[i][j] for j in ['GO_id', 'Rank_in_weight', 'Term', 'Annotated', 'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']]
+            df.loc[i] = [GO_dict[i][j] for j in ['GO_id', 'Rank_in_weight', 'Term', 'Annotated',
+                                                 'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']]
 
-        writer=pd.ExcelWriter('/lustre/home/xuyuxing/Work/Gel/orcWGD/Ks/WGD/'+test_node+".OG_level.xlsx")
+        writer = pd.ExcelWriter(
+            '/lustre/home/xuyuxing/Work/Gel/orcWGD/Ks/WGD/'+test_node+".OG_level.xlsx")
         df.to_excel(writer)
         writer.save()
 
@@ -672,46 +684,55 @@ if __name__ == '__main__':
     from collections import Counter
 
     sum_OG_counter = Counter(sum_OG_list)
-    core_Kp_OG = [i for i in sum_OG_counter if sum_OG_counter[i] >=3]
+    core_Kp_OG = [i for i in sum_OG_counter if sum_OG_counter[i] >= 3]
 
     GO_dict = GO_enrichment_by_topGO(core_Kp_OG, back_OG_dict, Ontology='BP')
 
-    df = pd.DataFrame(columns=(['GO_id', 'Rank_in_weight', 'Term', 'Annotated', 'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']))
+    df = pd.DataFrame(columns=(['GO_id', 'Rank_in_weight', 'Term', 'Annotated',
+                                'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']))
 
     for i in GO_dict:
-        df.loc[i] = [GO_dict[i][j] for j in ['GO_id', 'Rank_in_weight', 'Term', 'Annotated', 'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']]
+        df.loc[i] = [GO_dict[i][j] for j in ['GO_id', 'Rank_in_weight', 'Term', 'Annotated',
+                                             'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']]
 
-    writer=pd.ExcelWriter('/lustre/home/xuyuxing/Work/Gel/orcWGD/Ks/WGD/coreKP.OG_level.xlsx')
+    writer = pd.ExcelWriter(
+        '/lustre/home/xuyuxing/Work/Gel/orcWGD/Ks/WGD/coreKP.OG_level.xlsx')
     df.to_excel(writer)
     writer.save()
-    
+
     # venn
-    import api.xuyuxing.plot.VennDiagram as venn
+    import toolbiox.api.xuyuxing.plot.VennDiagram as venn
 
     for test_node in fore_OG_dict:
         labels, set_collections = venn.get_labels([fore_OG_dict[test_node], list(set(core_Kp_OG))], fill=['number'],
-                                            return_set_collections=True)
-                
-        print(test_node, labels, int(labels['11'])/(int(labels['11'])+int(labels['10'])))
+                                                  return_set_collections=True)
 
+        print(test_node, labels, int(
+            labels['11'])/(int(labels['11'])+int(labels['10'])))
 
     for test_node in fore_OG_dict:
         labels, set_collections = venn.get_labels([list(set(fore_OG_dict[test_node] + fore_OG_dict['N4'])), list(set(core_Kp_OG))], fill=['number'],
-                                            return_set_collections=True)
-        
-        print(test_node, labels, int(labels['11'])/(int(labels['11'])+int(labels['10'])))
+                                                  return_set_collections=True)
+
+        print(test_node, labels, int(
+            labels['11'])/(int(labels['11'])+int(labels['10'])))
 
     # N46
-    only_N46_list = list(set(fore_OG_dict['N6'] + fore_OG_dict['N4']) - set(core_Kp_OG))
+    only_N46_list = list(
+        set(fore_OG_dict['N6'] + fore_OG_dict['N4']) - set(core_Kp_OG))
 
-    GO_dict = GO_enrichment_by_topGO(only_N46_list, back_OG_dict, Ontology='BP')
+    GO_dict = GO_enrichment_by_topGO(
+        only_N46_list, back_OG_dict, Ontology='BP')
 
-    df = pd.DataFrame(columns=(['GO_id', 'Rank_in_weight', 'Term', 'Annotated', 'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']))
+    df = pd.DataFrame(columns=(['GO_id', 'Rank_in_weight', 'Term', 'Annotated',
+                                'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']))
 
     for i in GO_dict:
-        df.loc[i] = [GO_dict[i][j] for j in ['GO_id', 'Rank_in_weight', 'Term', 'Annotated', 'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']]
+        df.loc[i] = [GO_dict[i][j] for j in ['GO_id', 'Rank_in_weight', 'Term', 'Annotated',
+                                             'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']]
 
-    writer=pd.ExcelWriter('/lustre/home/xuyuxing/Work/Gel/orcWGD/Ks/WGD/only_N46.OG_level.xlsx')
+    writer = pd.ExcelWriter(
+        '/lustre/home/xuyuxing/Work/Gel/orcWGD/Ks/WGD/only_N46.OG_level.xlsx')
     df.to_excel(writer)
     writer.save()
 
@@ -720,16 +741,18 @@ if __name__ == '__main__':
 
     GO_dict = GO_enrichment_by_topGO(N46_list, back_OG_dict, Ontology='BP')
 
-    df = pd.DataFrame(columns=(['GO_id', 'Rank_in_weight', 'Term', 'Annotated', 'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']))
+    df = pd.DataFrame(columns=(['GO_id', 'Rank_in_weight', 'Term', 'Annotated',
+                                'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']))
 
     for i in GO_dict:
-        df.loc[i] = [GO_dict[i][j] for j in ['GO_id', 'Rank_in_weight', 'Term', 'Annotated', 'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']]
+        df.loc[i] = [GO_dict[i][j] for j in ['GO_id', 'Rank_in_weight', 'Term', 'Annotated',
+                                             'Significant', 'Expected', 'Rank_in_classic', 'classic', 'KS', 'weight']]
 
-    writer=pd.ExcelWriter('/lustre/home/xuyuxing/Work/Gel/orcWGD/Ks/WGD/N46.OG_level.xlsx')
+    writer = pd.ExcelWriter(
+        '/lustre/home/xuyuxing/Work/Gel/orcWGD/Ks/WGD/N46.OG_level.xlsx')
     df.to_excel(writer)
     writer.save()
 
-
     # -----------------
     # get speciation Ks
     work_dir = '/lustre/home/xuyuxing/Work/Gel/orcWGD/Ks/speciation'
@@ -738,12 +761,12 @@ if __name__ == '__main__':
     OG_tsv_file = '/lustre/home/xuyuxing/Work/Gel/orcWGD/orthofinder_old/pt_file/OrthoFinder/Results_Jun01/Orthogroups/Orthogroups.tsv'
     ref_xlsx = '/lustre/home/xuyuxing/Work/Gel/Gene_Loss2/S44_version3/Gel_ref.xlsx'
 
-    from lib.common.evolution.orthotools2 import OrthoGroups, read_species_info
-    from lib.common.fileIO import read_list_file
-    from lib.common.genome.genome_feature2 import Gene
-    from lib.common.genome.seq_base import read_fasta_by_faidx
+    from toolbiox.lib.common.evolution.orthotools2 import OrthoGroups, read_species_info
+    from toolbiox.lib.common.fileIO import read_list_file
+    from toolbiox.lib.common.genome.genome_feature2 import Gene
+    from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx
     from Bio import Phylo
-    from lib.common.evolution.tree_operate import draw_ascii, add_clade_name, lookup_by_names
+    from toolbiox.lib.common.evolution.tree_operate import draw_ascii, add_clade_name, lookup_by_names
 
     # read species
     species_tree = Phylo.read(species_tree_file, 'newick')
@@ -772,7 +795,7 @@ if __name__ == '__main__':
             continue
         s1 = test_node.clades[0]
         s2 = test_node.clades[1]
-        
+
         sp1 = [i.name for i in s1.get_terminals()]
         sp2 = [i.name for i in s2.get_terminals()]
 
@@ -797,24 +820,17 @@ if __name__ == '__main__':
                     gene.model_cds_seq = sp_info_dict[sp_id].cds_dict[gene.id].seq
                     sp2_gene_list.append(gene)
 
-
             for i in sp1_gene_list:
                 for j in sp2_gene_list:
                     if i == j:
                         continue
                     spec_pair_seq[(i, j)] = (og_id, test_node_id)
-    
+
     Ks_dict = get_gene_pair_Ks(list(spec_pair_seq.keys()))
 
-
-    
-
-
     import pickle
 
     pyb_file = '/lustre/home/xuyuxing/Work/Gel/orcWGD/Ks/speciation/all_Ks_gene_pair_dict.pyb'
     OUT = open(pyb_file, 'wb')
     pickle.dump((spec_pair_seq, Ks_dict), OUT)
     OUT.close()
-
-
