@@ -2,15 +2,15 @@ import os
 import re
 import gzip
 import pickle
-from lib.common.util import printer_list
-from lib.common.genome.seq_base import FastaRecord, read_fasta
-from api.common.genome.blast import blast_to_sqlite
+from toolbiox.lib.common.util import printer_list
+from toolbiox.lib.common.genome.seq_base import FastaRecord, read_fasta
+from toolbiox.api.common.genome.blast import blast_to_sqlite
 from Bio.Phylo.BaseTree import Tree
-from lib.common.fileIO import tsv_file_dict_parse
-from lib.common.math.set import merge_same_element_set
+from toolbiox.lib.common.fileIO import tsv_file_dict_parse
+from toolbiox.lib.common.math.set import merge_same_element_set
 from collections import OrderedDict
-from lib.common.genome.genome_feature2 import Gene, GeneSet
-from lib.common.os import multiprocess_running
+from toolbiox.lib.common.genome.genome_feature2 import Gene, GeneSet
+from toolbiox.lib.common.os import multiprocess_running
 
 
 def mclmatrix_parser(file_name):
