@@ -2,14 +2,14 @@ import os
 import re
 from Bio import Phylo
 from io import StringIO
-from lib.common.fileIO import tsv_file_dict_parse
-from lib.common.math.set import merge_same_element_set
-from lib.common.os import have_file, mkdir, copy_file, move_file, cmd_run, multiprocess_running
-from lib.common.genome.seq_base import read_fasta_by_faidx
-from lib.common.evolution.tree_operate import add_clade_name, lookup_by_names, ignore_branch_length, clade_rename, get_root_by_species_for_file, get_nhx_tree_with_taxon_info, get_offspring, load_nhx_tree, get_rooted_tree_by_species_tree, map_node_species_info, get_top_taxon_clade
-from lib.common.evolution.orthotools2 import OrthoGroup, OrthoGroups, get_orthogroups_from_gene_tree, OG_gene_rename
-from api.xuyuxing.comp_genome.dlcpar import run_dlcpar, merge_locus_tree_and_recon_file
-from api.xuyuxing.comp_genome.orthofinder_tree_resolve.main import resolve_rooted_gene_tree
+from toolbiox.lib.common.fileIO import tsv_file_dict_parse
+from toolbiox.lib.common.math.set import merge_same_element_set
+from toolbiox.lib.common.os import have_file, mkdir, copy_file, move_file, cmd_run, multiprocess_running
+from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx
+from toolbiox.lib.common.evolution.tree_operate import add_clade_name, lookup_by_names, ignore_branch_length, clade_rename, get_root_by_species_for_file, get_nhx_tree_with_taxon_info, get_offspring, load_nhx_tree, get_rooted_tree_by_species_tree, map_node_species_info, get_top_taxon_clade
+from toolbiox.lib.common.evolution.orthotools2 import OrthoGroup, OrthoGroups, get_orthogroups_from_gene_tree, OG_gene_rename
+from toolbiox.api.xuyuxing.comp_genome.dlcpar import run_dlcpar, merge_locus_tree_and_recon_file
+from toolbiox.api.xuyuxing.comp_genome.orthofinder_tree_resolve.main import resolve_rooted_gene_tree
 
 # about tree building
 
@@ -620,7 +620,7 @@ def get_orthogroups_pipeline(OGs, taxonomy_level=None, conserved_arguments=None,
 
 if __name__ == '__main__':
 
-    from lib.common.evolution.orthotools2 import OrthoGroups, read_species_info
+    from toolbiox.lib.common.evolution.orthotools2 import OrthoGroups, read_species_info
 
     ref_xlsx = '/lustre/home/xuyuxing/Work/Gel/orcWGD_redo/genome_info.xlsx'
     OG_tsv_file = "/lustre/home/xuyuxing/Work/Gel/orcWGD_redo/phylogenomics/orthofinder/pt_file/OrthoFinder/Results_Jul26/Orthogroups/Orthogroups.tsv"
