@@ -1,10 +1,10 @@
-from config import plant_tribes_scaffold_dir, plant_tribes_default_scaffold, hmmsearch_path, cap3_path, transdecoder_path, gt_path, trimal_path, cd_hit_dir_path, diamond_path, hmmpress_path, hmmbuild_path, clustalo_path
-from lib.common.evolution.orthotools2 import read_species_info, OrthoGroups
-from lib.common.fileIO import read_list_file, tsv_file_dict_parse
-from lib.common.genome.seq_base import BioSeq, read_fasta_by_faidx, reverse_complement, read_fasta
-from lib.common.os import cmd_run, mkdir, multiprocess_running, rmdir, move_file, get_file_name, get_file_dir
-from lib.xuyuxing.base.base_function import merge_file
-from lib.xuyuxing.base.common_command import merge_dict
+from toolbiox.config import plant_tribes_scaffold_dir, plant_tribes_default_scaffold, hmmsearch_path, cap3_path, transdecoder_path, gt_path, trimal_path, cd_hit_dir_path, diamond_path, hmmpress_path, hmmbuild_path, clustalo_path
+from toolbiox.lib.common.evolution.orthotools2 import read_species_info, OrthoGroups
+from toolbiox.lib.common.fileIO import read_list_file, tsv_file_dict_parse
+from toolbiox.lib.common.genome.seq_base import BioSeq, read_fasta_by_faidx, reverse_complement, read_fasta
+from toolbiox.lib.common.os import cmd_run, mkdir, multiprocess_running, rmdir, move_file, get_file_name, get_file_dir
+from toolbiox.lib.xuyuxing.base.base_function import merge_file
+from toolbiox.lib.xuyuxing.base.common_command import merge_dict
 from retry import retry
 from scipy import stats
 import numpy as np
@@ -1039,7 +1039,7 @@ def MapGenomeToOrthoGroups_main():
 
 
 if __name__ == '__main__':
-    from lib.common.evolution.orthotools2 import read_species_info, OrthoGroups
+    from toolbiox.lib.common.evolution.orthotools2 import read_species_info, OrthoGroups
 
     species_info_file = "/lustre/home/xuyuxing/Work/Orobanchaceae/gene_loss/Oro_ref.xlsx"
     orthogroups_file = "/lustre/home/xuyuxing/Work/Orobanchaceae/gene_loss/tree/orthologous_OGs.tsv"
@@ -1063,7 +1063,7 @@ if __name__ == '__main__':
                        scaffold_dir, num_threads)
 
     # classify a sequence
-    from lib.common.genome.seq_base import BioSeq
+    from toolbiox.lib.common.genome.seq_base import BioSeq
     protein_seq = BioSeq("MGQCYGKTIPTGDNDGPATTITTIAAAAEDLPEQTPPRNGTPSVKNTPARSSANSPWPSPYPSAAGTPAGVSPSTARSTPRRFFKKPFPPPSPAKHIRASLRKLGQRKKPPREGPIPEDADAGESEQQQQHALDKNFGYNKNFGAKYELGKEVGRGHFGHTCCAKGRKGELKDIPLAVKIISKAQFEKRTGHHECDSDLDMSDVKLIKDHKSEEDFRLLDPNLIDIFRFGYLQSYETGSYLIKAMVFMMTTAISIEDVRREVKILKALSGHRHLASFYDACEDSNNVYIIMELCEGGELLDRILAKGGKYSEDEAKLIIVQILSVVSFCHLQGVVHRDLKPENFLFTSRSEDADLKLIDFGLSDFIRTVGCLSLCIISHVLILSDERLNDIVGSAYYVAPEVLHRSYSVEADIWSIGVIAYILLCGSRPFWARTESGIFRAVLRADPNFEDLPWPSVSLEAKDFVRRLLNKDYRKRMTAAQALTHPWLRSESHPIPLDILVYKLVKSYLHATPFKRAALKALSKALTEDELIYLRAQFMLLEPSEDGRVSLENFRKISGSSHLALSLRNNILLPNTLELCDFQLLFANTAGLLHFSIFQALARNATDALNMSRVPDILNSMAPLSFRRMDLEEFCAAAISTYQLEALENWEQIASTAFEFFEQEGNRAISVEELARELNVGPSAHPMLRDWLRRDGKLSLVGYTKFLHGLTLRSSNMRHH", seqname="T4170N0C00004G00375")
     scaffold_dir = "/lustre/home/xuyuxing/Work/Orobanchaceae/gene_loss/gene_loss/Ocu/test2"
     work_dir = "/lustre/home/xuyuxing/Work/Orobanchaceae/gene_loss/gene_loss/Ocu/test2/test"
