@@ -1,10 +1,10 @@
-from config import plant_tribes_scaffold_dir, plant_tribes_default_scaffold, hmmsearch_path, cap3_path, transdecoder_path, gt_path, trimal_path, cd_hit_dir_path, diamond_path, hmmpress_path, hmmbuild_path, clustalo_path
-from lib.common.evolution.orthotools2 import read_species_info, OrthoGroups
-from lib.common.fileIO import read_list_file, tsv_file_dict_parse
-from lib.common.genome.seq_base import BioSeq, read_fasta_by_faidx, reverse_complement, read_fasta
-from lib.common.os import cmd_run, mkdir, multiprocess_running, rmdir, move_file, get_file_name, get_file_dir
-from lib.xuyuxing.base.base_function import merge_file
-from lib.xuyuxing.base.common_command import merge_dict
+from toolbiox.config import plant_tribes_scaffold_dir, plant_tribes_default_scaffold, hmmsearch_path, cap3_path, transdecoder_path, gt_path, trimal_path, cd_hit_dir_path, diamond_path, hmmpress_path, hmmbuild_path, clustalo_path
+from toolbiox.lib.common.evolution.orthotools2 import read_species_info, OrthoGroups
+from toolbiox.lib.common.fileIO import read_list_file, tsv_file_dict_parse
+from toolbiox.lib.common.genome.seq_base import BioSeq, read_fasta_by_faidx, reverse_complement, read_fasta
+from toolbiox.lib.common.os import cmd_run, mkdir, multiprocess_running, rmdir, move_file, get_file_name, get_file_dir
+from toolbiox.lib.xuyuxing.base.base_function import merge_file
+from toolbiox.lib.xuyuxing.base.common_command import merge_dict
 from retry import retry
 from scipy import stats
 import numpy as np
@@ -629,7 +629,7 @@ def seq_classify_main(args):
 
 
 if __name__ == '__main__':
-    from lib.common.evolution.orthotools2 import read_species_info, OrthoGroups
+    from toolbiox.lib.common.evolution.orthotools2 import read_species_info, OrthoGroups
 
     species_info_file = "/lustre/home/xuyuxing/Work/Orobanchaceae/gene_loss/Oro_ref.xlsx"
     orthogroups_file = "/lustre/home/xuyuxing/Work/Orobanchaceae/gene_loss/tree/orthologous_OGs.tsv"
@@ -657,9 +657,9 @@ if __name__ == '__main__':
 
     import os
     import re
-    from lib.common.genome.seq_base import read_fasta
-    from api.xuyuxing.comp_genome.planttribes2 import if_seq_in_ortho
-    from lib.common.os import multiprocess_running
+    from toolbiox.lib.common.genome.seq_base import read_fasta
+    from toolbiox.api.xuyuxing.comp_genome.planttribes2 import if_seq_in_ortho
+    from toolbiox.lib.common.os import multiprocess_running
 
     hmm_out_file = '/lustre/home/xuyuxing/Work/Orobanchaceae/HGT/3.init_filter/3.1.seqclassify/hmm/all.input.fasta.tbl'
 
@@ -700,8 +700,8 @@ if __name__ == '__main__':
     Tri_ver_filter_output = "/lustre/home/xuyuxing/Work/Orobanchaceae/HGT/3.init_filter/3.1.seqclassify/Reh_glu/output.filter.txt"
     Tri_ver_ctm = "/lustre/home/xuyuxing/Work/Orobanchaceae/HGT/3.init_filter/3.1.seqclassify/Reh_glu/no.ctm.id"
 
-    from lib.common.fileIO import read_list_file
-    from lib.common.fileIO import tsv_file_dict_parse
+    from toolbiox.lib.common.fileIO import read_list_file
+    from toolbiox.lib.common.fileIO import tsv_file_dict_parse
 
     Tri_ver_ctm_list = set(read_list_file(Tri_ver_ctm))
 
