@@ -2,8 +2,8 @@ import sys
 
 sys.path.append("/lustre/home/xuyuxing/python_project/Genome_work_tools/")
 from BCBio import GFF
-from api.xuyuxing.file_parser.fileIO import dict_to_tsv_file
-from lib.common.os import md5sum_maker
+from toolbiox.api.xuyuxing.file_parser.fileIO import dict_to_tsv_file
+from toolbiox.lib.common.os import md5sum_maker
 import re
 import gzip
 import os
