@@ -2,17 +2,17 @@ import os
 import re
 import pickle
 from pyfaidx import Fasta
-from lib.common.util import printer_list
-from lib.common.util import logging_init, configure_parser
-from lib.common.os import mkdir, copy_file, cmd_run, multiprocess_running
-from src.xuyuxing.tools.seqtools import split_fasta
-from lib.common.genome.seq_base import read_fasta
+from toolbiox.lib.common.util import printer_list
+from toolbiox.lib.common.util import logging_init, configure_parser
+from toolbiox.lib.common.os import mkdir, copy_file, cmd_run, multiprocess_running
+from toolbiox.src.xuyuxing.tools.seqtools import split_fasta
+from toolbiox.lib.common.genome.seq_base import read_fasta
 from argparse import Namespace
-from api.xuyuxing.genome.annotation_shell_code import *
-from lib.common.genome.genome_feature2 import read_gff_file
-from api.xuyuxing.resource.dfam import build_TE_class_tree
-from api.xuyuxing.resource.dfam import dfam_TE_classes_file as defaults_dfam_file
-from lib.common.evolution.tree_operate import lookup_by_names
+from toolbiox.api.xuyuxing.genome.annotation_shell_code import *
+from toolbiox.lib.common.genome.genome_feature2 import read_gff_file
+from toolbiox.api.xuyuxing.resource.dfam import build_TE_class_tree
+from toolbiox.api.xuyuxing.resource.dfam import dfam_TE_classes_file as defaults_dfam_file
+from toolbiox.lib.common.evolution.tree_operate import lookup_by_names
 
 
 class Maker_P_Job(object):
@@ -835,8 +835,8 @@ def parse_maker_repeat_results(results_gff_file, te_tree, add_map_dict=None, que
 
 
 if __name__ == '__main__':
-    from api.xuyuxing.resource.dfam import get_seq_anntation, build_TE_class_tree
-    from lib.common.fileIO import read_list_file
+    from toolbiox.api.xuyuxing.resource.dfam import get_seq_anntation, build_TE_class_tree
+    from toolbiox.lib.common.fileIO import read_list_file
 
     add_map_dict = {
         ('Satellite', 'subtelo'): ('Tandem_Repeat', 'Satellite', 'Subtelomeric'),
@@ -867,7 +867,7 @@ if __name__ == '__main__':
 
     #
 
-    from lib.common.math.interval import merge_intervals, sum_interval_length
+    from toolbiox.lib.common.math.interval import merge_intervals, sum_interval_length
 
 
     def gf_sum_length(gf_list):
