@@ -1,8 +1,8 @@
 jf_file = '/lustre/home/xuyuxing/Database/Gel/other/Aof/sra_data/ERR2040729.jf'
 
-from lib.xuyuxing.base.base_function import cmd_open
-from lib.common.util import printer_list
-from lib.common.os import cmd_run
+from toolbiox.lib.xuyuxing.base.base_function import cmd_open
+from toolbiox.lib.common.util import printer_list
+from toolbiox.lib.common.os import cmd_run
 
 
 def jf_file_parse(jf_file):
