@@ -2,11 +2,11 @@ import os
 import re
 import pickle
 from pyfaidx import Fasta
-from lib.common.util import printer_list
-from lib.common.util import logging_init
-from lib.common.os import mkdir, copy_file, cmd_run, multiprocess_running
-from src.xuyuxing.tools.seqtools import split_fasta
-from lib.common.genome.seq_base import read_fasta
+from toolbiox.lib.common.util import printer_list
+from toolbiox.lib.common.util import logging_init
+from toolbiox.lib.common.os import mkdir, copy_file, cmd_run, multiprocess_running
+from toolbiox.src.xuyuxing.tools.seqtools import split_fasta
+from toolbiox.lib.common.genome.seq_base import read_fasta
 
 
 # maker_p repeat
