@@ -8,7 +8,7 @@ import matplotlib
 matplotlib.use('Agg')
 
 import matplotlib.pyplot as plt
-import api.xuyuxing.plot.VennDiagram as venn
+import toolbiox.api.xuyuxing.plot.VennDiagram as venn
 
 labels = venn.get_labels([range(10), range(5, 15)], fill=['number', 'logic'])
 fig, ax = venn.venn2(labels, names=['list 1', 'list 2'])
