@@ -5,7 +5,7 @@ matplotlib.use('Agg')
 import matplotlib.pyplot as plt
 import sys
 sys.path.append("/lustre/home/xuyuxing/python_project/Genome_work_tools/")
-from lib.common.fileIO import tsv_file_dict_parse
+from toolbiox.lib.common.fileIO import tsv_file_dict_parse
 data_file = "/lustre/home/xuyuxing/Work/Other/tmp/printdata.txt"
 
 data_dict = tsv_file_dict_parse(data_file)
