@@ -1,7 +1,7 @@
-import lib.common.os
-from lib.common.fileIO import tsv_file_dict_parse
-from lib.xuyuxing.evolution.taxonomy import read_tax_record_dict_db
-import lib.xuyuxing.base.base_function as bf
+import toolbiox.lib.common.os
+from toolbiox.lib.common.fileIO import tsv_file_dict_parse
+from toolbiox.lib.xuyuxing.evolution.taxonomy import read_tax_record_dict_db
+import toolbiox.lib.xuyuxing.base.base_function as bf
 import xml.etree.ElementTree as ET
 import re
 import os
@@ -280,7 +280,7 @@ def get_ncbi_md5_list(ftp_dir, tmp_file="/tmp/tmp_md5.txt"):
 
 def get_many_ncbi_md5_list(ftp_dir_list, md5sum_huge_file, tmp_dir="/tmp/tmp_md5"):
     import time
-    from lib.xuyuxing.base.common_command import log_print
+    from toolbiox.lib.xuyuxing.base.common_command import log_print
 
     lib.common.os.mkdir(tmp_dir)
     #
@@ -345,7 +345,7 @@ def get_many_ncbi_md5_list(ftp_dir_list, md5sum_huge_file, tmp_dir="/tmp/tmp_md5
 
 def ncbi_files_download(ftp_list, output_list):
     import time
-    from lib.xuyuxing.base.common_command import log_print
+    from toolbiox.lib.xuyuxing.base.common_command import log_print
 
     log_print("\t\tBegin: download %d files from ncbi database" % len(ftp_list))
     start_time = time.time()
@@ -552,8 +552,8 @@ def class_genome_record_by_rank(record_dict, taxon_rank, tax_sqldb_file):
 
 
 if __name__ == '__main__':
-    from lib.common.os import mkdir
-    from lib.xuyuxing.evolution.taxonomy import build_taxon_database, store_tax_record_into_sqlite
+    from toolbiox.lib.common.os import mkdir
+    from toolbiox.lib.xuyuxing.evolution.taxonomy import build_taxon_database, store_tax_record_into_sqlite
 
     # normal
     work_dir = "/lustre/home/xuyuxing/Work/Gel/HGT"
@@ -602,7 +602,7 @@ if __name__ == '__main__':
                                              ['4751'])
 
     # merge ncbi and jgi database
-    from lib.xuyuxing.base.common_command import merge_dict
+    from toolbiox.lib.xuyuxing.base.common_command import merge_dict
 
     record_dict = merge_dict([ncbi_fungi_record_dict, jgi_fungi_record_dict], False)
 
