@@ -10,14 +10,14 @@ __author__ = 'Yuxing Xu'
 
 import re
 
-import lib.common.os
-import lib.xuyuxing.base.base_function as bf
-from lib.xuyuxing.base.common_command import log_print
+import toolbiox.lib.common.os
+import toolbiox.lib.xuyuxing.base.base_function as bf
+from toolbiox.lib.xuyuxing.base.common_command import log_print
 import time
-import lib.common.sqlite_command as sc
+import toolbiox.lib.common.sqlite_command as sc
 import sqlite3
 from functools import cmp_to_key
-from lib.xuyuxing.evolution.taxonomy import read_tax_record_dict_db, read_tax_name_record_dict_db
+from toolbiox.lib.xuyuxing.evolution.taxonomy import read_tax_record_dict_db, read_tax_name_record_dict_db
 
 
 class GenomeRecord(object):
@@ -45,8 +45,8 @@ def build_ncbi_genome_database(assembly_summary_genbank_file, assembly_summary_r
     :return: a dict
     """
 
-    from api.xuyuxing.file_parser.fileIO import tsv_file_parse
-    from lib.xuyuxing.base.common_command import dict2class
+    from toolbiox.api.xuyuxing.file_parser.fileIO import tsv_file_parse
+    from toolbiox.lib.xuyuxing.base.common_command import dict2class
     parse_file_db = tsv_file_parse(assembly_summary_genbank_file)
     genbank_record_dict = dict2class(parse_file_db, GenomeRecord, col_name)
     parse_file_db = tsv_file_parse(assembly_summary_refseq_file)
@@ -276,7 +276,7 @@ def print_sorted_class_taxon_rank_dict_from_sqlite(db_file, txt_file):
 
 
 def ascp_download(online_path, down_path, printer=False):
-    from config import ascp_path
+    from toolbiox.config import ascp_path
     cmd_string = ascp_path + " -v -i ~/.aspera/connect/etc/asperaweb_id_dsa.openssh -k 1 -T -l 200m anonftp@ftp-private.ncbi.nlm.nih.gov:%s %s" % (
         online_path, down_path)
 
@@ -292,7 +292,7 @@ def ascp_download(online_path, down_path, printer=False):
 
 
 def wget_download(online_path, down_path, printer=False):
-    from config import wget_path
+    from toolbiox.config import wget_path
     # cmd_string = wget_path + " -t 0 -O %s ftp://ftp.ncbi.nlm.nih.gov%s" % (
     #     down_path, online_path)
     cmd_string = wget_path + " -t 0 -O %s %s" % (
@@ -351,8 +351,8 @@ def genome_download(record_tmp, root_dir, want_download):
     :param want_download:
     :return:
     """
-    from lib.common.os import md5sum_check
-    from api.xuyuxing.file_parser.fileIO import tsv_file_parse
+    from toolbiox.lib.common.os import md5sum_check
+    from toolbiox.api.xuyuxing.file_parser.fileIO import tsv_file_parse
     data_dir = root_dir + "/data/NCBI"
 
     # parameter access
@@ -421,7 +421,7 @@ if __name__ == '__main__':
     ftp://ftp.ncbi.nlm.nih.gov/genomes/ASSEMBLY_REPORTS/assembly_summary_refseq.txt
     ftp://ftp.ncbi.nlm.nih.gov/genomes/ASSEMBLY_REPORTS/species_genome_size.txt.gz (need decompressed)
     """
-    from lib.xuyuxing.evolution.taxonomy import build_taxon_database, store_tax_record_into_sqlite
+    from toolbiox.lib.xuyuxing.evolution.taxonomy import build_taxon_database, store_tax_record_into_sqlite
 
     work_dir = '/lustre/home/xuyuxing/Database/NCBI/genome'
 
