@@ -9,9 +9,9 @@ import sys
 import operator
 import math
 from collections import OrderedDict
-from lib.xuyuxing.math.set_operating import jaccord_index
-from api.xuyuxing.plot.path_patch import scale_to_give_size, line_segment_plot
-from lib.xuyuxing.base.common_command import num_to_chr
+from toolbiox.lib.xuyuxing.math.set_operating import jaccord_index
+from toolbiox.api.xuyuxing.plot.path_patch import scale_to_give_size, line_segment_plot
+from toolbiox.lib.xuyuxing.base.common_command import num_to_chr
 import networkx as nx
 
 
@@ -19,7 +19,7 @@ __author__ = 'Yuxing Xu'
 
 """
 from Bio import Phylo
-from lib.common.evolution.tree_operate import add_clade_name
+from toolbiox.lib.common.evolution.tree_operate import add_clade_name
 
 tree_file = "/Users/yuxingxu/Downloads/SpeciesTreeAlignment.fa.raxml.bestTree"
 tree = Phylo.read(tree_file, 'newick')
@@ -1307,7 +1307,7 @@ def draw_tree(ax, tree):
 #
 #     if args_dict["subcommand_name"] == "get_close_node_info":
 #
-#         from lib.common.fileIO import tsv_file_dict_parse
+#         from toolbiox.lib.common.fileIO import tsv_file_dict_parse
 #
 #         tax_info_dict = tsv_file_dict_parse(args.taxon_info, fieldnames=["taxon_id", "speci_ID"], key_col="speci_ID",
 #                                             seq=",")
@@ -1328,7 +1328,7 @@ def draw_tree(ax, tree):
 #             if leaf_speci_hash[leaf.name] == args.target_speci:
 #                 target_leaf.append(leaf.name)
 #
-#         # from lib.resource.ncbi_taxonomy import build_taxon_database
+#         # from toolbiox.lib.resource.ncbi_taxonomy import build_taxon_database
 #         #
 #         # tax_record_dict = build_taxon_database(taxonomy_dir)
 #         #
@@ -1629,7 +1629,7 @@ if __name__ == '__main__':
     draw_ascii(tree)
 
     # work with nhx tree file
-    from lib.common.fileIO import tsv_file_dict_parse
+    from toolbiox.lib.common.fileIO import tsv_file_dict_parse
 
     normal_gene_tree_file = "/lustre/home/xuyuxing/Work/Gel/orcWGD_redo/phylogenomics_old/tree/fasttree/OG0002678/tree.phb"
     species_tree_file = "/lustre/home/xuyuxing/Work/Gel/orcWGD_redo/species.tree.txt"
