@@ -157,7 +157,8 @@ class mRNA(GenomeFeature):
         self.cDNA_seq = feature_seq_extract(
             self.sub_features, genome_file, "exon")
 
-        good_orf, phase, aa_seq, cds_seq = cds_judgment(self.cds_seq, parse_phase=True, keep_stop=False, return_cds=True)
+        good_orf, phase, aa_seq, cds_seq = cds_judgment(
+            self.cds_seq, parse_phase=True, keep_stop=False, return_cds=True)
 
         self.cds_seq = cds_seq
         self.aa_seq = aa_seq
@@ -175,15 +176,16 @@ class mRNA(GenomeFeature):
         max_s = max([i[0] for i in exon_interval_list] + [i[1]
                                                           for i in exon_interval_list])
 
-        intron_list_already = [i for i in sub_gf_traveler(self) if i.type == 'intron']
+        intron_list_already = [
+            i for i in sub_gf_traveler(self) if i.type == 'intron']
         for i in intron_list_already:
             self.sub_features.remove(i)
-        
+
         intron_interval_list = interval_minus_set(
             (min_s, max_s), exon_interval_list)
         intron_interval_list = sorted(
             intron_interval_list, key=lambda x: x[0], reverse=(self.strand == '-'))
-       
+
         intron_list = []
         num = 1
         for i in intron_interval_list:
@@ -338,6 +340,8 @@ class Genome(object):
             contig_len = self.genome_seq[contig_id].seqs_length()
             self.chromosomes[contig_id] = Chromosome(id=contig_id, species=self.species, version=self.version,
                                                      length=contig_len)
+            self.chromosomes[contig_id].load_genome_features(self.feature_dict)
+            self.chromosomes[contig_id].build_index()
 
     def genome_feature_parse(self):
         # check needed files
@@ -789,11 +793,11 @@ def get_mRNA_overlap(mRNA1, mRNA2, similarity_type):
 
 def cds_judgment(cds_sequence, parse_phase=True, keep_stop=False, return_cds=False):
     """make sure a cds seq is good for translate"""
-    
+
     if parse_phase:
         phase = 0
         orf_dict = {}
-        
+
         for i in range(3):
             cds_now = cds_sequence[i:]
             aa_seq = translate(cds_now, to_stop=False)
@@ -803,11 +807,13 @@ def cds_judgment(cds_sequence, parse_phase=True, keep_stop=False, return_cds=Fal
             else:
                 one_star_aa_seq = aa_seq
             phase = i
-            orf_dict[phase] = (phase, one_star_aa_seq, cds_now[:len(one_star_aa_seq)*3])
+            orf_dict[phase] = (phase, one_star_aa_seq,
+                               cds_now[:len(one_star_aa_seq)*3])
 
-        best_phase = sorted(orf_dict, key=lambda x:len(orf_dict[x][1]), reverse=True)[0]
+        best_phase = sorted(orf_dict, key=lambda x: len(
+            orf_dict[x][1]), reverse=True)[0]
 
-        phase, one_star_aa_seq, cds_now = orf_dict[best_phase] 
+        phase, one_star_aa_seq, cds_now = orf_dict[best_phase]
 
         if len(one_star_aa_seq) * 3 / len(cds_sequence) > 0.95:
             good_orf = True
@@ -837,7 +843,8 @@ def cds_judgment(cds_sequence, parse_phase=True, keep_stop=False, return_cds=Fal
         else:
             one_star_aa_seq = aa_seq
 
-        good_orf = True if len(cds_sequence) % 3 == 0 and len(one_star_aa_seq) == len(cds_sequence) / 3 else False
+        good_orf = True if len(cds_sequence) % 3 == 0 and len(
+            one_star_aa_seq) == len(cds_sequence) / 3 else False
 
         if not keep_stop and '*' in one_star_aa_seq:
             out_aa_seq = one_star_aa_seq[:-1]
@@ -961,15 +968,17 @@ def mRNA_rename(raw_mRNA, mRNA_new_name, gene_new_name=None, chr_new_name=None):
     return new_mRNA
 
 
-def gene_rename(raw_gene, gene_new_name, chr_new_name):
+def gene_rename(raw_gene, gene_new_name, chr_new_name, keep_old_id=True):
     # new_qualifiers
     new_qualifiers = {
         'ID': [gene_new_name],
         'Name': [gene_new_name],
         'source': ['RENAME'],
-        'old_id': [raw_gene.id],
     }
 
+    if keep_old_id:
+        new_qualifiers['old_id'] = [raw_gene.id]
+
     # new_sub_features
     mRNA_list = [gf for gf in raw_gene.sub_features if gf.type == 'mRNA']
 
@@ -1102,7 +1111,7 @@ def add_gfs_into_db(gf_list, db_file_name):
         sc.drop_index(db_file_name, table_name + '_index')
     except:
         pass
-    
+
     sc.build_index(db_file_name, table_name, 'gf_name')
 
     return db_file_name
@@ -1158,7 +1167,7 @@ def get_gf_from_db(db_file_name, contig_name=None, start=None, end=None, strand=
         gf_dict[gf.id] = gf
 
     return gf_dict
-    
+
 # def add_gfs_into_db(gf_list, db_file_name, max_table_row=10000):
 #     """
 
@@ -1576,7 +1585,6 @@ if __name__ == '__main__':
 
     gf_dict = get_gf_from_db(db_file_name, gf_name_list=gf_name_list[:10])
 
-
     # gff_file = '/lustre/home/xuyuxing/Work/Gel/Gene_Loss/plant/all_map/test/T267555N0.genome.gff3'
     # gff_file = '/lustre/home/xuyuxing/Database/Phelipanche/annotation/maker_p/maker_1M/Pae.results.gff'
     # db_file_name = '/lustre/home/xuyuxing/Work/Gel/Gene_Loss/plant/all_map/test/Cau/test.gff.db'
