@@ -11,7 +11,7 @@ from pyfaidx import Fasta
 from toolbiox.lib.common.util import logging_init
 import toolbiox.lib.common.sqlite_command as sc
 from toolbiox.lib.common.os import remove_file_name_suffix, cmd_run
-# from lib.common.genome.genome_feature2 import cds_judgment
+# from toolbiox.lib.common.genome.genome_feature2 import cds_judgment
 
 
 # tools for seq as string
@@ -1040,8 +1040,8 @@ def BIG_id_parse(nt_file, gzip_flag=False):
 def PreExtractNr(nr_fasta_file, sql3_db_file):
     import time
     import sqlite3
-    from lib.xuyuxing.base.common_command import log_print
-    import lib.common.sqlite_command as sc
+    from toolbiox.lib.xuyuxing.base.common_command import log_print
+    import toolbiox.lib.common.sqlite_command as sc
 
     start_time = time.time()
     table_columns_dict = {
@@ -1091,7 +1091,7 @@ def PreExtractNr(nr_fasta_file, sql3_db_file):
 
 
 def ExtractNr(nr_fasta_file, key_IDs, output_file, short_name=True):
-    from lib.common.sqlite_command import sqlite_select_by_a_key
+    from toolbiox.lib.common.sqlite_command import sqlite_select_by_a_key
     name_IDs = sqlite_select_by_a_key(
         nr_fasta_file, "name_record", "accession_id", key_IDs)
     seq_IDs = tuple(set([i[2] for i in name_IDs]))
@@ -1273,7 +1273,7 @@ if __name__ == '__main__':
 
     # from Bio import SeqIO
     #
-    # from lib.base.base_function import cmd_run
+    # from toolbiox.lib.base.base_function import cmd_run
     #
     # # build
     # a = SeqIO.index_db('/lustre/home/xuyuxing/Work/Other/saif/jupyter/A188.rename.fa.gz.idx',
