@@ -1,17 +1,17 @@
-import re
-import lib.common.sqlite_command as sc
-import sqlite3
-import copy
 from Bio.Phylo.BaseTree import Tree, Clade
-from lib.common.evolution.tree_operate import remove_pass_node, lookup_by_names, get_offspring, draw_ascii, add_clade_name, \
-    get_parent, get_ancestors, get_MRCA, get_sons
-from lib.xuyuxing.math.stats import get_qvalue
-from scipy import stats
-from lib.common.util import printer_list
-from mlxtend.evaluate import permutation_test
-import numpy as np
-from lib.common.math.set import merge_subset
 from itertools import combinations
+from mlxtend.evaluate import permutation_test
+from scipy import stats
+from toolbiox.lib.common.evolution.tree_operate import Clade, Phylo, reroot_by_outgroup_clade, add_clade_name, lookup_by_names, get_MRCA, remove_given_node_from_tree, remove_pass_node, get_offspring, draw_ascii, get_parent, get_ancestors, get_sons
+from toolbiox.lib.common.fileIO import tsv_file_dict_parse
+from toolbiox.lib.common.math.set import merge_subset
+from toolbiox.lib.common.util import printer_list
+from toolbiox.lib.xuyuxing.math.stats import get_qvalue
+import copy
+import numpy as np
+import re
+import sqlite3
+import toolbiox.lib.common.sqlite_command as sc
 
 
 class Taxon(object):
@@ -47,8 +47,8 @@ class Taxon(object):
         return lineage_list[::-1]
 
     def check_rank(self, tax_record_dict):
-        from lib.xuyuxing.math.set_operating import uniqify
-        from lib.xuyuxing.math.lcs import lcs
+        from toolbiox.lib.xuyuxing.math.set_operating import uniqify
+        from toolbiox.lib.xuyuxing.math.lcs import lcs
         for i in tax_record_dict:
             temp_list = tuple(
                 uniqify([j[1] for j in tax_record_dict[i].get_lineage(tax_record_dict) if
@@ -59,7 +59,8 @@ class Taxon(object):
                 raise ValueError
 
     def lower_than(self, rank, tax_record_dict):
-        temp_list = tuple([j[1] for j in self.get_lineage(tax_record_dict) if j[1] != 'no rank' and j[1] != 'clade'])
+        temp_list = tuple([j[1] for j in self.get_lineage(
+            tax_record_dict) if j[1] != 'no rank' and j[1] != 'clade'])
 
         if len(temp_list) == 0:  # Other sequence
             return False
@@ -72,7 +73,7 @@ class Taxon(object):
             return False
 
     def is_child_of(self, tax_id, tax_record_dict=None):
-        if isinstance(self.get_lineage,list):
+        if isinstance(self.get_lineage, list):
             parent_list = self.get_lineage
         else:
             parent_list = self.get_lineage(tax_record_dict)
@@ -84,7 +85,7 @@ class Taxon(object):
 
     def is_ancestor_of(self, tax_id, tax_record_dict):
         taget_tax = tax_record_dict[tax_id]
-        if isinstance(taget_tax.get_lineage,list):
+        if isinstance(taget_tax.get_lineage, list):
             parent_list = tax_record_dict[tax_id].get_lineage
         else:
             parent_list = tax_record_dict[tax_id].get_lineage(tax_record_dict)
@@ -179,7 +180,10 @@ def get_MRCA_taxon_id(taxon_id_list, tax_record_dict):
     lineage_sum_list = []
     for tax_id in taxon_id_list:
         tax_tmp = tax_record_dict[tax_id]
-        lineage_list = tax_tmp.get_lineage(tax_record_dict)
+        try:
+            lineage_list = tax_tmp.get_lineage(tax_record_dict)
+        except:
+            lineage_list = tax_tmp.get_lineage
         lineage_sum_list.append(lineage_list)
 
     range_num = min([len(i) for i in lineage_sum_list])
@@ -195,10 +199,11 @@ def get_MRCA_taxon_id(taxon_id_list, tax_record_dict):
 
 def store_tax_record_into_sqlite(tax_record_dict, db_file):
     import time
-    from lib.xuyuxing.base.common_command import log_print
+    from toolbiox.lib.xuyuxing.base.common_command import log_print
     log_print("\t\tBegin: convert NCBI taxonomy database to sqlite3 file")
     start_time = time.time()
-    column_name = ["tax_id", "sci_name", "parent_tax_id", "rank", "merged_new_id", "lineage"]
+    column_name = ["tax_id", "sci_name", "parent_tax_id",
+                   "rank", "merged_new_id", "lineage"]
     sc.init_sql_db(db_file, "tax_record", column_name)
     num = 0
     record_tmp_dict = []
@@ -239,7 +244,8 @@ def store_tax_record_into_sqlite(tax_record_dict, db_file):
         # sc.insert_one_record_to_sql_table(tuple(record_tmp), tuple(column_name), db_file, "tax_record")
 
         if num % 10000 == 0:
-            sc.sqlite_write(record_tmp_dict, db_file, "tax_record", column_name)
+            sc.sqlite_write(record_tmp_dict, db_file,
+                            "tax_record", column_name)
             record_tmp_dict = []
 
         round_time = time.time()
@@ -261,7 +267,8 @@ def store_tax_record_into_sqlite(tax_record_dict, db_file):
 
 class Taxon_db(Taxon):
     def lower_than(self, rank):
-        temp_list = tuple([j[1] for j in self.get_lineage if j[1] != 'no rank' and j[1] != 'clade'])
+        temp_list = tuple(
+            [j[1] for j in self.get_lineage if j[1] != 'no rank' and j[1] != 'clade'])
 
         if len(temp_list) == 0:  # Other sequence
             return False
@@ -281,9 +288,11 @@ class Taxon_db(Taxon):
 
 
 def read_tax_record_dict_db(db_file, tax_id_list=[]):
-    column_name = ["tax_id", "sci_name", "parent_tax_id", "rank", "merged_new_id", "lineage"]
+    column_name = ["tax_id", "sci_name", "parent_tax_id",
+                   "rank", "merged_new_id", "lineage"]
 
-    record_tuple_list = sc.sqlite_select_by_a_key(db_file, "tax_record", "tax_id", tuple(tax_id_list))
+    record_tuple_list = sc.sqlite_select_by_a_key(
+        db_file, "tax_record", "tax_id", tuple(tax_id_list))
 
     record_dict = {}
     for record_tuple in record_tuple_list:
@@ -299,7 +308,8 @@ def read_tax_record_dict_db(db_file, tax_id_list=[]):
             record.tax_id = record_tuple[4]
             record.older = True
 
-        record.get_lineage = [tuple(i.split(":")) for i in record_tuple[5].split(";")]
+        record.get_lineage = [tuple(i.split(":"))
+                              for i in record_tuple[5].split(";")]
 
         lineage_list = record.get_lineage
         # taxon.lineage = lineage_list
@@ -313,9 +323,11 @@ def read_tax_record_dict_db(db_file, tax_id_list=[]):
 
 
 def read_tax_name_record_dict_db(db_file, tax_name_list):
-    column_name = ["tax_id", "sci_name", "parent_tax_id", "rank", "merged_new_id", "lineage"]
+    column_name = ["tax_id", "sci_name", "parent_tax_id",
+                   "rank", "merged_new_id", "lineage"]
 
-    record_tuple_list = sc.sqlite_select_by_a_key(db_file, "tax_record", "sci_name", tuple(tax_name_list))
+    record_tuple_list = sc.sqlite_select_by_a_key(
+        db_file, "tax_record", "sci_name", tuple(tax_name_list))
 
     record_dict = {}
     for record_tuple in record_tuple_list:
@@ -331,7 +343,8 @@ def read_tax_name_record_dict_db(db_file, tax_name_list):
             record.tax_id = record_tuple[4]
             record.older = True
 
-        record.get_lineage = [tuple(i.split(":")) for i in record_tuple[5].split(";")]
+        record.get_lineage = [tuple(i.split(":"))
+                              for i in record_tuple[5].split(";")]
 
         lineage_list = record.get_lineage
         # taxon.lineage = lineage_list
@@ -346,20 +359,26 @@ def read_tax_name_record_dict_db(db_file, tax_name_list):
 
 def tax_id_list(db_file):
     conn = sqlite3.connect(db_file)
-    record_tuple = [i[0] for i in conn.execute("select tax_id from tax_record").fetchall()]
+    record_tuple = [i[0] for i in conn.execute(
+        "select tax_id from tax_record").fetchall()]
     conn.close()
     return record_tuple
 
 
 def get_common_tree(taxon_id_list, taxon_dict):
     MRCA = get_MRCA_taxon_id(taxon_id_list, taxon_dict)
-    clade_MRCA = Clade(branch_length=None, name=MRCA, clades=None, confidence=None, color=None, width=None)
+    clade_MRCA = Clade(branch_length=None, name=MRCA,
+                       clades=None, confidence=None, color=None, width=None)
     clade_dict = {
         MRCA: clade_MRCA
     }
 
     for taxon_id in taxon_id_list:
-        lineage = [i[0] for i in taxon_dict[taxon_id].get_lineage(taxon_dict)]
+        try:
+            lineage = [i[0]
+                       for i in taxon_dict[taxon_id].get_lineage(taxon_dict)]
+        except:
+            lineage = [i[0] for i in taxon_dict[taxon_id].get_lineage]
 
         for taxon_id_tmp in lineage:
             taxon_id_tmp_index = lineage.index(taxon_id_tmp)
@@ -425,14 +444,16 @@ def blast_taxon_assign(taxon_score_list, common_tree, silence=True):
     if not silence:
         print("# based on rank and fisher exact test:")
 
-    taxon_score_rank = sorted(taxon_hash, key=lambda x: taxon_hash[x], reverse=True)
+    taxon_score_rank = sorted(
+        taxon_hash, key=lambda x: taxon_hash[x], reverse=True)
     taxon_score_rank = [i for i in taxon_score_rank if i in tree_dict]
 
     fisher_p_dict = {}
 
     for clade in common_tree.find_clades(order='preorder'):
         all_sub_clade_id = [i.name for i in get_offspring(clade) + [clade]]
-        all_sub_clade_have_hit = list(set(all_sub_clade_id) & set(taxon_id_list))
+        all_sub_clade_have_hit = list(
+            set(all_sub_clade_id) & set(taxon_id_list))
 
         top_hit_num = 0
         for i in all_sub_clade_have_hit:
@@ -456,7 +477,8 @@ def blast_taxon_assign(taxon_score_list, common_tree, silence=True):
                        fisher_qvalue_dict[i] <= 0.05]
 
     if not silence:
-        print("# There are %d taxon have q_value <= 0.05" % len(good_clade_name))
+        print("# There are %d taxon have q_value <= 0.05" %
+              len(good_clade_name))
 
     # based on score value to say how
     # compared between brother score
@@ -468,14 +490,18 @@ def blast_taxon_assign(taxon_score_list, common_tree, silence=True):
 
             if len(parent_tmp) != 0:
                 clade_leaf = clade_tmp.get_terminals()
-                brother_leaf = [i for i in parent_tmp.get_terminals() if i not in clade_leaf]
+                brother_leaf = [
+                    i for i in parent_tmp.get_terminals() if i not in clade_leaf]
 
-                clade_score = [taxon_hash[i.name] for i in clade_leaf if i.name in taxon_hash]
-                brother_score = [taxon_hash[i.name] for i in brother_leaf if i.name in taxon_hash]
+                clade_score = [taxon_hash[i.name]
+                               for i in clade_leaf if i.name in taxon_hash]
+                brother_score = [taxon_hash[i.name]
+                                 for i in brother_leaf if i.name in taxon_hash]
 
                 p_value = permutation_test(clade_score, brother_score,
                                            method='approximate',
-                                           func=lambda x, y: np.mean(x) - np.mean(y),
+                                           func=lambda x, y: np.mean(
+                                               x) - np.mean(y),
                                            seed=0)
 
                 permutation_p_value[clade_name] = p_value
@@ -495,7 +521,8 @@ def blast_taxon_assign(taxon_score_list, common_tree, silence=True):
 
     full_supported_list = []
     for clade_name in good_clade_name:
-        lineage_list = [i.name for i in get_ancestors(clade_name, common_tree)] + [clade_name]
+        lineage_list = [i.name for i in get_ancestors(
+            clade_name, common_tree)] + [clade_name]
         if set(lineage_list) & set(good_clade_name) == set(lineage_list):
             full_supported_list.append(clade_name)
 
@@ -504,13 +531,15 @@ def blast_taxon_assign(taxon_score_list, common_tree, silence=True):
     # get best lineage
     good_clade_lineage_list = []
     for clade_name in full_supported_list:
-        lineage_list = [i.name for i in get_ancestors(clade_name, common_tree)] + [clade_name]
+        lineage_list = [i.name for i in get_ancestors(
+            clade_name, common_tree)] + [clade_name]
         good_clade_lineage_list.append(lineage_list)
 
     # if have two good lineage, use vote way
     merge_set_list = merge_subset(good_clade_lineage_list)
 
-    vote_dict = {tuple(i): 0 for i in good_clade_lineage_list if set(i) in merge_set_list}
+    vote_dict = {tuple(i): 0 for i in good_clade_lineage_list if set(
+        i) in merge_set_list}
 
     for i in good_clade_lineage_list:
         for j in vote_dict:
@@ -521,7 +550,8 @@ def blast_taxon_assign(taxon_score_list, common_tree, silence=True):
         num = 0
         for i in sorted(vote_dict, key=lambda x: vote_dict[x], reverse=True):
             print("#( %d ):" % num)
-            lineage_txt = printer_list([taxon_dict[j].sci_name for j in i], head="\t", sep=";")
+            lineage_txt = printer_list(
+                [taxon_dict[j].sci_name for j in i], head="\t", sep=";")
             print(lineage_txt)
             print("Vote num: %d\n" % (vote_dict[i]))
             num = num + 1
@@ -537,13 +567,16 @@ def blast_taxon_assign(taxon_score_list, common_tree, silence=True):
     while len(good_lineage_list) > 1:
         for comp_pair in combinations(good_lineage_list, 2):
             if not silence:
-                print("\tcompare with %s vs %s:" % (comp_pair[0][-1], comp_pair[1][-1]))
+                print("\tcompare with %s vs %s:" %
+                      (comp_pair[0][-1], comp_pair[1][-1]))
 
             A_clade = tree_dict[comp_pair[0][-1]]
             B_clade = tree_dict[comp_pair[1][-1]]
             mrca_clade = get_MRCA(A_clade, B_clade, common_tree)
-            A_conflict_clade = [i for i in get_sons(mrca_clade) if i.name in comp_pair[0]][0]
-            B_conflict_clade = [i for i in get_sons(mrca_clade) if i.name in comp_pair[1]][0]
+            A_conflict_clade = [i for i in get_sons(
+                mrca_clade) if i.name in comp_pair[0]][0]
+            B_conflict_clade = [i for i in get_sons(
+                mrca_clade) if i.name in comp_pair[1]][0]
 
             A_conflict_score = [taxon_hash[i.name] for i in A_conflict_clade.get_terminals() if
                                 i.name in taxon_hash]
@@ -552,7 +585,8 @@ def blast_taxon_assign(taxon_score_list, common_tree, silence=True):
 
             p_value = permutation_test(A_conflict_score, B_conflict_score,
                                        method='approximate',
-                                       func=lambda x, y: np.mean(x) - np.mean(y),
+                                       func=lambda x, y: np.mean(
+                                           x) - np.mean(y),
                                        seed=0)
             if not silence:
                 print("\tp_value: %f" % p_value)
@@ -575,11 +609,13 @@ def blast_taxon_assign(taxon_score_list, common_tree, silence=True):
                     [i.name for i in get_ancestors(mrca_clade.name, common_tree)] + [mrca_clade.name])
                 good_lineage_list.append(mrca_lineage)
                 if not silence:
-                    print("\tremove %s and %s, change to %s\n" % (comp_pair[0][-1], comp_pair[1][-1], mrca_clade.name))
+                    print("\tremove %s and %s, change to %s\n" %
+                          (comp_pair[0][-1], comp_pair[1][-1], mrca_clade.name))
 
             merge_set_list = merge_subset(good_lineage_list)
 
-            good_lineage_list = [tuple(i) for i in good_clade_lineage_list if set(i) in merge_set_list]
+            good_lineage_list = [
+                tuple(i) for i in good_clade_lineage_list if set(i) in merge_set_list]
 
             break
 
@@ -597,7 +633,8 @@ def blast_taxon_assign(taxon_score_list, common_tree, silence=True):
 
             rename_dict[i] = sci_name
 
-        draw_ascii(common_tree, column_width=160, clade_name=True, rename_dict=rename_dict)
+        draw_ascii(common_tree, column_width=160,
+                   clade_name=True, rename_dict=rename_dict)
 
     if good_lineage_list == []:
         recommand_taxon = MRCA
@@ -607,3 +644,100 @@ def blast_taxon_assign(taxon_score_list, common_tree, silence=True):
         recommand_taxon_fisher = fisher_qvalue_dict[good_lineage_list[0][-1]]
 
     return MRCA, recommand_taxon, recommand_taxon_fisher
+
+
+# use 1kp
+
+def load_one_kp_tree(one_kp_tree_file, acc_to_taxon_map):
+    acc_map_dict = tsv_file_dict_parse(acc_to_taxon_map, fieldnames=[
+                                       'acc', 'tax_id', 'lineage'], key_col='acc')
+
+    one_kp_tree = Phylo.read(one_kp_tree_file, 'newick')
+    one_kp_tree = add_clade_name(one_kp_tree)
+    one_kp_node_dict = lookup_by_names(one_kp_tree)
+
+    outgroup = ['DZPJ', 'RAWF']
+    out_clade = get_MRCA(
+        one_kp_node_dict[outgroup[0]], one_kp_node_dict[outgroup[1]], one_kp_tree)
+
+    one_kp_rooted_tree, one_kp_rooted_node_dict = reroot_by_outgroup_clade(
+        one_kp_tree, one_kp_node_dict, out_clade.name, False)
+
+    return one_kp_rooted_tree, one_kp_rooted_node_dict, acc_map_dict
+
+
+def extract_common_tree(one_kp_tree, keep_leave_list):
+
+    node_name_list = [i.name for i in one_kp_tree.get_terminals()]
+    valid_keep_leave_list = list(set(keep_leave_list) & set(node_name_list))
+    removed_node_list = list(set(node_name_list) - set(valid_keep_leave_list))
+
+    removed_tree = remove_given_node_from_tree(one_kp_tree, removed_node_list)
+
+    for c in removed_tree.find_clades():
+        if c.branch_length:
+            c.branch_length = None
+
+    return removed_tree
+
+
+def get_best_1kp_represent(input_taxon_id_list, acc_map_dict, taxon_db_file):
+
+    acc_taxon_list = list(set([acc_map_dict[i]['tax_id']
+                               for i in acc_map_dict]))
+    taxon_dict = read_tax_record_dict_db(
+        taxon_db_file, tax_id_list=input_taxon_id_list + acc_taxon_list)
+
+    rep_dict = {}
+    for i in input_taxon_id_list:
+
+        if i in set(acc_taxon_list):
+            rep_dict[i] = i
+        else:
+            it = taxon_dict[i]
+            it_lineage = set([j[0] for j in it.get_lineage])
+
+            ca_dict = {}
+            for a in acc_taxon_list:
+                at = taxon_dict[a]
+                at_lineage = set([j[0] for j in at.get_lineage])
+                ca_dict[a] = list(it_lineage & at_lineage)
+
+            best_rep_ca_num = len(
+                ca_dict[sorted(acc_taxon_list, key=lambda x:len(ca_dict[x]), reverse=True)[0]])
+            best_rep = sorted([j for j in acc_taxon_list if len(
+                ca_dict[j]) == best_rep_ca_num])[0]
+            rep_dict[i] = best_rep
+
+    for i in rep_dict:
+        rep_dict[i] = sorted(
+            [j for j in acc_map_dict if acc_map_dict[j]['tax_id'] == rep_dict[i]])[0]
+
+    return rep_dict
+
+
+def get_common_tree_by_1kp(input_taxon_id_list, one_kp_tree_file, acc_to_taxon_map, taxon_db_file):
+
+    one_kp_rooted_tree, one_kp_rooted_node_dict, acc_map_dict = load_one_kp_tree(
+        one_kp_tree_file, acc_to_taxon_map)
+    rep_dict = get_best_1kp_represent(
+        input_taxon_id_list, acc_map_dict, taxon_db_file)
+
+    removed_tree = extract_common_tree(
+        one_kp_rooted_tree, set([rep_dict[i] for i in rep_dict]))
+    removed_tree = add_clade_name(removed_tree)
+    removed_tree_dict = lookup_by_names(removed_tree)
+
+    okp2input_dict = {}
+    for i in rep_dict:
+        okp2input_dict.setdefault(rep_dict[i], []).append(i)
+
+    for okp in okp2input_dict:
+        input_it_list = okp2input_dict[okp]
+        if len(input_it_list) > 1:
+            clade_list = [Clade(name=i, clades=[]) for i in input_it_list]
+            removed_tree_dict[okp].clades = clade_list
+        else:
+            removed_tree_dict[okp].name = input_it_list[0]
+
+    return removed_tree
