@@ -1,5 +1,5 @@
 from Bio import Phylo
-from lib.common.evolution.tree_operate import add_clade_name
+from toolbiox.lib.common.evolution.tree_operate import add_clade_name
 
 tree_file = "/Users/yuxingxu/Job/Work/HGT/treeplot/tree.phb"
 tree = Phylo.read(tree_file, 'newick')
