@@ -1,9 +1,9 @@
-import lib.common.os
-import lib.xuyuxing.base.base_function as bf
-from lib.common.genome.seq_base import read_fasta_big, sub_seq
-from lib.common.fileIO import tsv_file_dict_parse
-from lib.common.math.interval import section, group_by_intervals
-from config import *
+import toolbiox.lib.common.os
+import toolbiox.lib.xuyuxing.base.base_function as bf
+from toolbiox.lib.common.genome.seq_base import read_fasta_big, sub_seq
+from toolbiox.lib.common.fileIO import tsv_file_dict_parse
+from toolbiox.lib.common.math.interval import section, group_by_intervals
+from toolbiox.config import *
 from collections import Counter
 import re
 import os
