@@ -1,8 +1,8 @@
-from lib.common.genome.genome_feature2 import read_gff_file
-from api.xuyuxing.file_parser.fileIO import tsv_file_parse
-from api.xuyuxing.genome.repeatmasker import repeatmasker_parser
-from lib.common.math.interval import merge_intervals, overlap_between_interval_set, sum_interval_length
-from lib.common.genome.seq_base import sequence_entropy, read_fasta_by_faidx
+from toolbiox.lib.common.genome.genome_feature2 import read_gff_file
+from toolbiox.api.xuyuxing.file_parser.fileIO import tsv_file_parse
+from toolbiox.api.xuyuxing.genome.repeatmasker import repeatmasker_parser
+from toolbiox.lib.common.math.interval import merge_intervals, overlap_between_interval_set, sum_interval_length
+from toolbiox.lib.common.genome.seq_base import sequence_entropy, read_fasta_by_faidx
 from interlap import InterLap
 
 
@@ -189,7 +189,7 @@ if __name__ == "__main__":
     Gelv2_gff = '/lustre/home/xuyuxing/Database/Gel/genome/annotation/v3.0/jbrowse/data/Gel.genome.gff3'
     Yuan_gff = '/lustre/home/xuyuxing/Database/Gel/genome/annotation/v3.0/yuan_pt_vs_xu/WPG_working/WPGmapper/yuan/genewise.best.gff'
 
-    from lib.common.genome.genome_feature2 import read_gff_file, get_mRNA_overlap, Gene, gene_compare, convert_dict_structure
+    from toolbiox.lib.common.genome.genome_feature2 import read_gff_file, get_mRNA_overlap, Gene, gene_compare, convert_dict_structure
 
     Gelv2_dict = read_gff_file(Gelv2_gff)
     Yuan_dict = read_gff_file(Yuan_gff)
@@ -219,10 +219,10 @@ if __name__ == "__main__":
     Gel_Pseudo_gff = '/lustre/home/xuyuxing/Work/Gel/Pseudogene/Gel.Pseudo.gff3'
     tran_evidence_gff = '/lustre/home/xuyuxing/Database/Gel/genome/annotation/v2.0/annotation_run/evm/T.gff3'
 
-    from lib.common.genome.genome_feature2 import read_gff_file, get_mRNA_overlap, Gene
+    from toolbiox.lib.common.genome.genome_feature2 import read_gff_file, get_mRNA_overlap, Gene
     from interlap import InterLap
-    from api.xuyuxing.file_parser.fileIO import tsv_file_parse
-    from lib.xuyuxing.math.set_operating import merge_intervals, overlap_between_interval_set, sum_interval_length
+    from toolbiox.api.xuyuxing.file_parser.fileIO import tsv_file_parse
+    from toolbiox.lib.xuyuxing.math.set_operating import merge_intervals, overlap_between_interval_set, sum_interval_length
 
     tmp_info = tsv_file_parse(identity_file)
 
@@ -444,8 +444,8 @@ if __name__ == "__main__":
     # merge
 
     import re
-    from lib.xuyuxing.base.common_command import merge_dict
-    from lib.common.genome.genome_feature2 import gene_rename, write_gff_file
+    from toolbiox.lib.xuyuxing.base.common_command import merge_dict
+    from toolbiox.lib.common.genome.genome_feature2 import gene_rename, write_gff_file
     import copy
 
     all_gf_list = []
@@ -502,7 +502,7 @@ if __name__ == "__main__":
         all_gf_list, '/lustre/home/xuyuxing/Database/Gel/genome/annotation/v3.0/merged.gff')
 
     # add fungi_pseudo_gene
-    from lib.common.genome.genome_feature2 import read_gff_file, convert_dict_structure, get_mRNA_overlap
+    from toolbiox.lib.common.genome.genome_feature2 import read_gff_file, convert_dict_structure, get_mRNA_overlap
 
     fungi_pseudo_gff = "/lustre/home/xuyuxing/Work/Gel/HGT_WPGmapper/pseudo/Gel.rep.gff3"
     Gelv3_gff = '/lustre/home/xuyuxing/Database/Gel/genome/annotation/v3.0/v3.1/Gel.genome.v3.0.gff'
@@ -541,7 +541,7 @@ if __name__ == "__main__":
 
     #
     import re
-    from lib.common.genome.genome_feature2 import gene_rename, write_gff_file
+    from toolbiox.lib.common.genome.genome_feature2 import gene_rename, write_gff_file
 
     gf_list = []
     for i in v3_gene_dict:
@@ -563,7 +563,7 @@ if __name__ == "__main__":
     # test
     gff_file = '/lustre/home/xuyuxing/Database/Gel/genome/annotation/v3.0/v3.1/Gel.genome.v3.1.gff'
 
-    from lib.common.genome.genome_feature2 import read_gff_file, get_mRNA_overlap, Gene, gene_compare, convert_dict_structure
+    from toolbiox.lib.common.genome.genome_feature2 import read_gff_file, get_mRNA_overlap, Gene, gene_compare, convert_dict_structure
 
     Gelv31_dict = read_gff_file(gff_file)
 
