@@ -1,4 +1,4 @@
-from lib.common.math.bin_and_window import split_sequence_to_bins
+from toolbiox.lib.common.math.bin_and_window import split_sequence_to_bins
 from pyfaidx import Fasta
 import pysam
 import io
