@@ -12,17 +12,17 @@ args.related_mit_genome = '/lustre/home/xuyuxing/Database/Lindenbergia/genome/hi
 """
 
 import os
-from lib.common.util import logging_init
-from src.xuyuxing.GenomeTools.rRNAFinder import rRNAFinder_main
-from src.xuyuxing.GenomeTools.ContigDepth import ContigDepth_main
-from lib.common.os import cmd_run, mkdir, copy_file
-from lib.common.genome.seq_base import read_fasta_by_faidx
-from src.xuyuxing.tools.seqtools import FragmentGenome_main
-from src.xuyuxing.tools.taxontools import DiamondTaxonAssign_main
-from src.xuyuxing.GenomeTools.ContaminationFilter import ContaminationFilter_main
-from config import taxon_nr_db, taxon_dump
-from api.common.genome.blast import outfmt6_read
-from lib.common.fileIO import tsv_file_dict_parse
+from toolbiox.lib.common.util import logging_init
+from toolbiox.src.xuyuxing.GenomeTools.rRNAFinder import rRNAFinder_main
+from toolbiox.src.xuyuxing.GenomeTools.ContigDepth import ContigDepth_main
+from toolbiox.lib.common.os import cmd_run, mkdir, copy_file
+from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx
+from toolbiox.src.xuyuxing.tools.seqtools import FragmentGenome_main
+from toolbiox.src.xuyuxing.tools.taxontools import DiamondTaxonAssign_main
+from toolbiox.src.xuyuxing.GenomeTools.ContaminationFilter import ContaminationFilter_main
+from toolbiox.config import taxon_nr_db, taxon_dump
+from toolbiox.api.common.genome.blast import outfmt6_read
+from toolbiox.lib.common.fileIO import tsv_file_dict_parse
 import matplotlib.pyplot as plt
 import numpy as np
 
