@@ -5,17 +5,17 @@ import pandas as pd
 from itertools import combinations
 from collections import Counter
 from interlap import InterLap
-from lib.common.os import multiprocess_running
-from lib.common.util import printer_list
-from lib.common.util import logging_init
-from api.xuyuxing.comp_genome.orthofinder import OG_tsv_file_parse
-from lib.common.sqlite_command import sqlite_execute
-from lib.common.math.bin_and_window import split_sequence_to_bins
-from lib.common.math.interval import overlap_between_interval_set, group_by_intervals_with_overlap_threshold
-from api.common.genome.blast import outfmt6_read_big
-from lib.common.genome.genome_feature2 import get_gf_db_meta_dict, gf_info_retrieval, write_gff_file, read_gff_file, get_mRNA_overlap, convert_dict_structure
-from lib.common.genome.seq_base import read_fasta_by_faidx, extract_seq_from_sqlite, write_fasta
-from src.xuyuxing.GenomeTools.WPGmapper import load_map_files, extract_all_evidences
+from toolbiox.lib.common.os import multiprocess_running
+from toolbiox.lib.common.util import printer_list
+from toolbiox.lib.common.util import logging_init
+from toolbiox.api.xuyuxing.comp_genome.orthofinder import OG_tsv_file_parse
+from toolbiox.lib.common.sqlite_command import sqlite_execute
+from toolbiox.lib.common.math.bin_and_window import split_sequence_to_bins
+from toolbiox.lib.common.math.interval import overlap_between_interval_set, group_by_intervals_with_overlap_threshold
+from toolbiox.api.common.genome.blast import outfmt6_read_big
+from toolbiox.lib.common.genome.genome_feature2 import get_gf_db_meta_dict, gf_info_retrieval, write_gff_file, read_gff_file, get_mRNA_overlap, convert_dict_structure
+from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx, extract_seq_from_sqlite, write_fasta
+from toolbiox.src.xuyuxing.GenomeTools.WPGmapper import load_map_files, extract_all_evidences
 
 
 def min_cds_start(cds_range_list):
