@@ -4,15 +4,15 @@ from itertools import combinations
 import networkx as nx
 from interlap import InterLap
 from collections import Counter
-from lib.common.genome.seq_base import read_fasta_by_faidx
-import lib.common.sqlite_command as sc
-from lib.common.os import mkdir, multiprocess_running
-from lib.common.genome.genome_feature2 import read_gff_file, get_gf_db_meta_dict, gf_info_retrieval, write_gff_file
-from lib.xuyuxing.math.set_operating import interval_length_sum
-from lib.common.math.interval import section, merge_intervals, interval_minus_set, overlap_between_interval_set, \
+from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx
+import toolbiox.lib.common.sqlite_command as sc
+from toolbiox.lib.common.os import mkdir, multiprocess_running
+from toolbiox.lib.common.genome.genome_feature2 import read_gff_file, get_gf_db_meta_dict, gf_info_retrieval, write_gff_file
+from toolbiox.lib.xuyuxing.math.set_operating import interval_length_sum
+from toolbiox.lib.common.math.interval import section, merge_intervals, interval_minus_set, overlap_between_interval_set, \
     group_by_intervals_with_overlap_threshold
-from api.xuyuxing.comp_genome.orthofinder import OG_tsv_file_parse
-from lib.xuyuxing.math.stats import get_threshold
+from toolbiox.api.xuyuxing.comp_genome.orthofinder import OG_tsv_file_parse
+from toolbiox.lib.xuyuxing.math.stats import get_threshold
 
 # about weight score
 def get_ortho_support(OG_tsv_file):
