@@ -14,18 +14,18 @@ from interlap import InterLap
 import pandas as pd
 from collections import Counter
 from itertools import combinations
-from lib.xuyuxing.math.set_operating import interval_length_sum
-from lib.common.math.interval import merge_intervals, interval_minus_set, overlap_between_interval_set, \
+from toolbiox.lib.xuyuxing.math.set_operating import interval_length_sum
+from toolbiox.lib.common.math.interval import merge_intervals, interval_minus_set, overlap_between_interval_set, \
     group_by_intervals_with_overlap_threshold
-from api.xuyuxing.plot import gene_structure_plot, exon_box
-import lib.common.sqlite_command as sc
-from lib.common.genome.genome_feature2 import read_gff_file, get_gf_db_meta_dict, gf_info_retrieval, write_gff_file
-from lib.common.genome.seq_base import read_fasta_by_faidx
-from api.xuyuxing.genome.repeatmasker import repeatmasker_parser
-from api.xuyuxing.genome.cd_hit import cd_hit_runing
-from lib.common.util import printer_list
-from lib.common.math.bin_and_window import split_sequence_to_bins
-from lib.common.os import mkdir, multiprocess_running
+from toolbiox.api.xuyuxing.plot import gene_structure_plot, exon_box
+import toolbiox.lib.common.sqlite_command as sc
+from toolbiox.lib.common.genome.genome_feature2 import read_gff_file, get_gf_db_meta_dict, gf_info_retrieval, write_gff_file
+from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx
+from toolbiox.api.xuyuxing.genome.repeatmasker import repeatmasker_parser
+from toolbiox.api.xuyuxing.genome.cd_hit import cd_hit_runing
+from toolbiox.lib.common.util import printer_list
+from toolbiox.lib.common.math.bin_and_window import split_sequence_to_bins
+from toolbiox.lib.common.os import mkdir, multiprocess_running
 
 
 def load_map_files(reference_genome_table, WPGmapper_dir):
