@@ -1,25 +1,25 @@
-from lib.common.os import mkdir, copy_file, cmd_run, multiprocess_running
-from lib.common.util import logging_init
-from lib.xuyuxing.evolution.orthotools import OG_tsv_file_parse
+from toolbiox.lib.common.os import mkdir, copy_file, cmd_run, multiprocess_running
+from toolbiox.lib.common.util import logging_init
+from toolbiox.lib.xuyuxing.evolution.orthotools import OG_tsv_file_parse
 import os
 import pandas as pd
-from lib.common.evolution.tree_operate import get_root_by_species, add_clade_name, lookup_by_names, reroot_by_outgroup_clade, collapse_low_support
+from toolbiox.lib.common.evolution.tree_operate import get_root_by_species, add_clade_name, lookup_by_names, reroot_by_outgroup_clade, collapse_low_support
 from Bio import Phylo
-from lib.common.fileIO import tsv_file_dict_parse, excel_file_parse
-from lib.common.math.interval import merge_intervals, overlap_between_interval_set, \
+from toolbiox.lib.common.fileIO import tsv_file_dict_parse, excel_file_parse
+from toolbiox.lib.common.math.interval import merge_intervals, overlap_between_interval_set, \
     group_by_intervals_with_overlap_threshold, sum_interval_length
 import pickle
 from collections import OrderedDict
-from api.xuyuxing.genome.genblasta import genblasta_run, genblasta_to_genewise
-from lib.common.genome.seq_base import read_fasta_by_faidx, read_fasta
-from config import wu_blast_path
+from toolbiox.api.xuyuxing.genome.genblasta import genblasta_run, genblasta_to_genewise
+from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx, read_fasta
+from toolbiox.config import wu_blast_path
 from BCBio import GFF
-from lib.common.genome.genome_feature2 import read_gff_file, sub_gf_traveler
+from toolbiox.lib.common.genome.genome_feature2 import read_gff_file, sub_gf_traveler
 from interlap import InterLap
-from api.common.genome.blast import outfmt6_read_big, evalue_to_wvalue
-from lib.xuyuxing.base.common_command import merge_dict
-from lib.common.evolution.tree_operate import monophyly
-from src.xuyuxing.tools.phytools import PtTree
+from toolbiox.api.common.genome.blast import outfmt6_read_big, evalue_to_wvalue
+from toolbiox.lib.xuyuxing.base.common_command import merge_dict
+from toolbiox.lib.common.evolution.tree_operate import monophyly
+from toolbiox.src.xuyuxing.tools.phytools import PtTree
 
 
 def if_conserved(species_list, conserved_arguments_dict):
